"""
The MIT License (MIT)

Copyright (c) 2015-present Rapptz
Copyright (c) 2015 Rossen Georgiev <rossen@rgp.io>
Copyright (c) 2020 James

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

This is a modified version of
https://github.com/Rapptz/discord.py/blob/master/discord/gateway.py
and https://github.com/ValvePython/steam/blob/master/steam/core/cm.py
"""

from __future__ import annotations

import asyncio
import concurrent.futures
import logging
import struct
import sys
import threading
import time
import traceback
from collections.abc import Callable
from dataclasses import dataclass
from datetime import timedelta
from gzip import FCOMMENT, FEXTRA, FHCRC, FNAME  # type: ignore
from typing import TYPE_CHECKING, Any, Generic, TypeVar
from zlib import MAX_WBITS, decompress

import aiohttp
import attr
from typing_extensions import TypeAlias

from . import utils
from .enums import PersonaState, PersonaStateFlag, Result
from .errors import NoCMsFound
from .iterators import AsyncIterator
from .models import Registerable, register, return_true
from .protobufs import EMsg, GCMsg, GCMsgProto, Msg, MsgProto
from .protobufs.client_server_2 import CMsgGcClient

if TYPE_CHECKING:
    from .client import Client
    from .enums import UIMode
    from .game import GameToDict
    from .protobufs import login
    from .protobufs.base import CMsgMulti
    from .state import ConnectionState


__all__ = (
    "ConnectionClosed",
    "CMServerList",
    "SteamWebSocket",
    "Msgs",
)

log = logging.getLogger(__name__)
Msgs: TypeAlias = "MsgProto[Any] | Msg[Any] | GCMsgProto[Any] | GCMsg[Any]"
M = TypeVar("M", bound=MsgProto[Any])
READ_U32 = struct.Struct("<I").unpack_from


@dataclass
class EventListener(Generic[M]):
    __slots__ = ("emsg", "check", "future")

    emsg: EMsg | None
    check: Callable[[M], bool]
    future: asyncio.Future[M]


if not TYPE_CHECKING:
    EventListener.__class_getitem__ = classmethod(lambda cls, params: cls)


@attr.dataclass(slots=True)
class CMServer:
    url: str
    score: float = 0.0


class ConnectionClosed(Exception):
    def __init__(self, cm: CMServer, cms: CMServerList):
        self.cm = cm
        self.cm_list = cms
        super().__init__(f"Connection to {self.cm.url}, has closed.")


class WebSocketClosure(Exception):
    """An exception to make up for the fact that aiohttp doesn't signal closure."""


class CMServerList(AsyncIterator[CMServer]):
    __slots__ = ("cms", "cell_id")

    def __init__(self, state: ConnectionState, first_cm_to_try: CMServer | None = None):
        super().__init__(state)
        self.cms: list[CMServer] = []
        self.cell_id = 0
        if first_cm_to_try is not None:
            self._append(first_cm_to_try)

    async def fill(self) -> None:
        if not await self.fetch_servers_from_api():
            raise NoCMsFound("No Community Managers could be found to connect to")

        if not self.cms:
            log.debug("No good servers left. Resetting...")
            self.reset_all()
            return await self.fill()

        for cm in await self.ping():
            self._append(cm)

    def clear(self) -> None:
        if self.cms:
            log.debug("List cleared.")
        self.cms = []

    async def fetch_servers_from_api(self, cell_id: int = 0) -> bool:
        log.debug("Attempting to fetch servers from the WebAPI")
        self.cell_id = cell_id
        try:
            resp = await self._state.http.get_cm_list(cell_id)
        except Exception as e:
            log.error(f"WebAPI fetch request failed with result: {e!r}")
            return False

        resp = resp["response"]
        if resp["result"] != Result.OK:
            log.error(
                f"Fetching the CMList failed with: Result: {Result(resp['result'])!r}. Message: {resp['message']!r}"
            )
            return False

        hosts = resp["serverlist_websockets"]
        log.debug(f"Received {len(hosts)} servers from WebAPI")

        self.cell_id = cell_id
        self.extend(hosts)

        return True

    def reset_all(self) -> None:
        log.debug("Marking all CM servers as good.")
        for cm in self.cms:
            cm.score = 0.0

    def extend(self, hosts: list[str]) -> None:
        total = len(self.cms)
        urls = [cm.url for cm in self.cms]
        for url in hosts:
            if url not in urls:
                self.cms.append(CMServer(url))
        if len(self.cms) > total:
            log.debug(f"Added {len(self.cms) - total} new CM server addresses.")

    async def ping(self) -> list[CMServer]:
        async def ping_cm(cm: CMServer) -> None:
            try:
                start = time.perf_counter()
                resp = await asyncio.wait_for(self._state.http._session.get(f"https://{cm.url}/cmping/"), timeout=5)
                latency = time.perf_counter() - start
                if resp.status != 200:
                    raise aiohttp.ClientError
                load = resp.headers["X-Steam-CMLoad"]
            except (KeyError, asyncio.TimeoutError, aiohttp.ClientError):
                try:
                    self.cms.remove(cm)
                except ValueError:
                    pass
            else:
                cm.score = (int(load) * 2) + latency
                best_cms.append(cm)

        best_cms = []
        await asyncio.gather(*(ping_cm(cm) for cm in self.cms))
        # TODO dynamically make sure we get good ones by doing maths or just check how the client does it
        log.debug("Finished pinging CMs")
        return sorted(best_cms, key=lambda cm: cm.score)


class KeepAliveHandler(threading.Thread):
    def __init__(self, ws: SteamWebSocket, interval: int):
        super().__init__()
        self.ws = ws
        self.interval = interval
        self._main_thread_id = self.ws.thread_id
        self.heartbeat = MsgProto(EMsg.ClientHeartBeat, send_reply=True)
        self.msg = "Keeping websocket alive with heartbeat %s."
        self.block_msg = "Heartbeat blocked for more than %s seconds."
        self.behind_msg = "Can't keep up, websocket is %.1fs behind."
        self._stop_ev = threading.Event()
        self._last_ack = time.perf_counter()
        self._last_send = time.perf_counter()
        self.latency = float("inf")

    def run(self) -> None:
        while not self._stop_ev.wait(self.interval):
            if self._last_recv + 60 < time.perf_counter():
                log.warning("CM %r has stopped responding to the gateway. Closing and restarting.", self.ws.cm)
                coro = self.ws.close(4000)
                f = asyncio.run_coroutine_threadsafe(coro, loop=self.ws.loop)

                try:
                    f.result()
                except Exception:
                    log.exception("An error occurred while stopping the gateway. Ignoring.")
                finally:
                    return self.stop()

            log.debug(self.msg, self.heartbeat)
            coro = self.ws.send_proto(self.heartbeat)
            f = asyncio.run_coroutine_threadsafe(coro, loop=self.ws.loop)
            # block until sending is complete
            total = 0
            try:
                while True:
                    try:
                        f.result(timeout=10)
                        break
                    except concurrent.futures.TimeoutError:
                        total += 10
                        try:
                            frame = sys._current_frames()[self._main_thread_id]  # noqa
                        except KeyError:
                            msg = self.block_msg
                        else:
                            stack = "".join(traceback.format_stack(frame))
                            msg = f"{self.block_msg}\nLoop thread traceback (most recent call last):\n{stack}"
                        log.warning(msg, total)

            except Exception:
                self.stop()
            else:
                self._last_send = time.perf_counter()

    def stop(self) -> None:
        self._stop_ev.set()

    def tick(self) -> None:
        self._last_recv = time.perf_counter()

    def ack(self) -> None:
        ack_time = time.perf_counter()
        self._last_ack = ack_time
        self.latency = ack_time - self._last_send
        if self.latency > 10:
            log.warning(self.behind_msg, self.latency)


class SteamWebSocket(Registerable):
    parsers: dict[EMsg, Callable[..., Any]]

    def __init__(
        self, state: ConnectionState, socket: aiohttp.ClientWebSocketResponse, cm_list: CMServerList, cm: CMServer
    ):
        self.socket = socket

        # state stuff
        self._connection = state
        self.cm_list = cm_list
        self.cm = cm
        # the keep alive
        self._keep_alive: KeepAliveHandler
        self._dispatch = state.dispatch
        self.thread_id = threading.get_ident()

        # ws related stuff
        self.listeners: list[EventListener[Any]] = []
        self.parsers.update(state.parsers)

        self.session_id = 0
        self.steam_id = state.client.user.id64
        self._current_job_id = 0
        self._gc_current_job_id = 0

    @property
    def latency(self) -> float:
        """Measures latency between a heartbeat send and the heartbeat interval in seconds."""
        return self._keep_alive.latency

    def wait_for(self, emsg: EMsg | None, check: Callable[[M], bool] = return_true) -> asyncio.Future[M]:
        future = self.loop.create_future()
        entry = EventListener[M](emsg=emsg, check=check, future=future)
        self.listeners.append(entry)
        return future

    @classmethod
    async def from_client(
        cls, client: Client, cm: CMServer | None = None, cm_list: CMServerList | None = None
    ) -> SteamWebSocket:
        state = client._connection
        cm_list = cm_list or CMServerList(state, cm)
        token = await client.token
        async for cm in cm_list:
            log.info(f"Attempting to create a websocket connection to: {cm}")
            socket = await client.http.connect_to_cm(cm.url)
            log.debug(f"Connected to {cm}")

            self = cls(state, socket, cm_list, cm)
            await self.send_proto(
                MsgProto(
                    EMsg.ClientLogon,
                    account_name=client.username,
                    web_logon_nonce=token,
                    client_os_type=4294966596,
                    protocol_version=65580,
                    chat_mode=2,
                    ui_mode=self._connection._ui_mode,
                    qos_level=2,
                )
            )
            self._dispatch("connect")
            return self
        raise NoCMsFound("No CMs found could be connected to")

    async def poll_event(self) -> None:
        try:
            message = await self.socket.receive()
            if message.type is aiohttp.WSMsgType.BINARY and message.data:  # it can sometimes be None/empty
                return await self.receive(message.data)
            if message.type is aiohttp.WSMsgType.ERROR:
                log.debug(f"Received {message}")
                raise message.data
            if message.type in (aiohttp.WSMsgType.CLOSED, aiohttp.WSMsgType.CLOSE, aiohttp.WSMsgType.CLOSING):
                log.debug(f"Received {message}")
                raise WebSocketClosure
            log.debug(f"Dropped unexpected message type: {message}")
        except WebSocketClosure:
            await self.handle_close()

    async def receive(self, message: bytes) -> None:
        (emsg_value,) = READ_U32(message)
        emsg = EMsg(utils.clear_proto_bit(emsg_value))

        try:
            msg = MsgProto(emsg, message) if utils.is_proto(emsg_value) else Msg(emsg, message, extended=True)
        except Exception as exc:
            return log.error(f"Failed to deserialize message: {emsg!r}, {message!r}", exc_info=exc)

        log.debug("Socket has received %r from the websocket.", msg)

        if hasattr(self, "_keep_alive"):
            self._keep_alive.tick()

        self._dispatch("socket_receive", msg)
        self.run_parser(emsg, msg)

        # remove the dispatched listener
        removed = []
        for idx, entry in enumerate(self.listeners):
            if entry.emsg != emsg and entry.emsg is not None:
                continue

            future = entry.future
            if future.cancelled():
                removed.append(idx)
                continue

            try:
                valid = entry.check(msg)
            except Exception as exc:
                future.set_exception(exc)
                removed.append(idx)
            else:
                if valid:
                    future.set_result(msg)
                    removed.append(idx)

        for idx in reversed(removed):
            del self.listeners[idx]

    async def send(self, data: bytes) -> None:
        try:
            await self.socket.send_bytes(data)
        except ConnectionResetError:
            log.info("Connection closed")
            await self.handle_close()

    async def send_proto(self, message: Msgs) -> None:
        message.steam_id = self.steam_id
        message.session_id = self.session_id

        self._dispatch("socket_send", message)
        await self.send(bytes(message))

    async def send_gc_message(self, msg: GCMsgProto[Any] | GCMsg[Any]) -> int:  # for ext's to send GC messages
        message = MsgProto[CMsgGcClient](
            EMsg.ClientToGC,
            appid=self._connection.client.GAME.id,  # type: ignore
            msgtype=utils.set_proto_bit(msg.msg) if isinstance(msg, GCMsgProto) else msg.msg,
        )
        message.body.payload = bytes(msg)
        message.header.body.routing_appid = self._connection.client.GAME.id  # type: ignore
        message.header.body.job_id_source = self._gc_current_job_id = (self._gc_current_job_id + 1) % 10000 or 1

        log.debug("Sending GC message %r", msg)
        self._dispatch("gc_message_send", msg)
        await self.send_proto(message)
        return message.header.body.job_id_source

    async def close(self, code: int = 1000) -> None:
        message = MsgProto(EMsg.ClientLogOff)
        message.steam_id = self.steam_id
        message.session_id = self.session_id
        await self.socket.close(code=code, message=bytes(message))

    @register(EMsg.ClientLoggedOff)
    async def handle_close(self, _=None) -> None:
        if not self.socket.closed:
            await self.close()
            self.cm_list.queue.pop()  # pop the disconnected cm
        if hasattr(self, "_keep_alive"):
            self._keep_alive.stop()
            del self._keep_alive
        log.info("Websocket closed, cannot reconnect.")
        raise ConnectionClosed(self.cm, self.cm_list)

    @register(EMsg.ClientLogOnResponse)
    async def handle_logon(self, msg: MsgProto[login.CMsgClientLogonResponse]) -> None:
        if msg.result != Result.OK:
            log.debug(f"Failed to login with result: {msg.result}")
            if msg.result == Result.InvalidPassword:
                http = self._connection.http
                await http.logout()
                await http.login(http.username, http.password, shared_secret=http.shared_secret)
            return await self.handle_close()

        self.session_id = msg.session_id
        self.cm_list.cell_id = msg.body.cell_id

        interval = msg.body.out_of_game_heartbeat_seconds
        self._keep_alive = KeepAliveHandler(ws=self, interval=interval)
        self._keep_alive.start()
        log.debug("Heartbeat started.")

        await self.send_um("ChatRoom.GetMyChatRoomGroups")
        await self.send_um("Player.GetEmoticonList")
        await self.change_presence(
            games=self._connection._games,
            state=self._connection._state,
            flags=self._connection._flags,
            force_kick=self._connection._force_kick,
        )
        await self.send_proto(MsgProto(EMsg.ClientRequestCommentNotifications))
        await self.send_proto(MsgProto(EMsg.ClientServerTimestampRequest, client_request_timestamp=time.time() * 1000))

        log.debug("Logon completed")

    @register(EMsg.ClientHeartBeat)
    def ack_heartbeat(self, msg: MsgProto[login.CMsgClientHeartBeat]) -> None:
        self._keep_alive.ack()

    @register(EMsg.ClientServerTimestampResponse)
    def set_steam_time(self, msg: MsgProto[login.CMsgClientServerTimestampResponse]) -> None:
        self.server_offset = timedelta(milliseconds=msg.body.server_timestamp_ms - msg.body.client_request_timestamp)

    @staticmethod
    def unpack_multi(msg: MsgProto[CMsgMulti]) -> bytes | None:
        data = msg.body.message_body
        log.debug(f"Decompressing payload ({len(data)} -> {msg.body.size_unzipped})")
        if data[:2] != b"\037\213":
            return log.info("Received a file that's not GZipped")

        (flag,) = struct.unpack("<B", data[3:4])
        position = 10

        if flag:  # this isn't ever hit, might as well save a few nanos
            if flag & FEXTRA:
                (extra_len,) = struct.unpack("<H", data[position:2])
                position += 2 + extra_len
            if flag & FNAME:
                while True:
                    terminator = data[position:1]
                    position += 1
                    if not terminator or terminator == b"\000":
                        break
            if flag & FCOMMENT:
                while True:
                    terminator = data[position:1]
                    position += 1
                    if not terminator or terminator == b"\000":
                        break
            if flag & FHCRC:
                position += 2

        decompressed = decompress(data[position:], wbits=-MAX_WBITS)

        if len(decompressed) != msg.body.size_unzipped:
            return log.info(f"Unzipped size mismatch for multi payload {msg}, discarding")

        return decompressed

    @register(EMsg.Multi)
    async def handle_multi(self, msg: MsgProto[CMsgMulti]) -> None:
        log.debug("Received a multi")
        data = self.unpack_multi(msg) if msg.body.size_unzipped else msg.body.message_body

        while data:
            (size,) = READ_U32(data)
            await self.receive(data[4 : 4 + size])
            data = data[4 + size :]

    @property
    def next_job_id(self) -> int:
        self._current_job_id = (self._current_job_id + 1) % 10000 or 1
        return self._current_job_id

    async def send_um(self, __name: str, **kwargs: Any) -> int:
        msg = MsgProto(EMsg.ServiceMethodCallFromClient, um_name=__name, **kwargs)
        msg.header.body.job_id_source = self.next_job_id
        await self.send_proto(msg)
        return msg.header.body.job_id_source

    async def send_um_and_wait(
        self,
        __name: str,
        check: Callable[[M], bool] | None = None,
        **kwargs: Any,
    ) -> M:
        job_id = await self.send_um(__name, **kwargs)
        check = check or (lambda msg: msg.header.body.job_id_target == job_id)
        return await self.wait_for(EMsg.ServiceMethodResponse, check=check)

    async def send_proto_and_wait(self, msg: Msgs, check: Callable[[M], bool] | None = None) -> M:
        msg.header.body.job_id_source = job_id = self.next_job_id
        await self.send_proto(msg)
        check = check or (lambda msg: msg.header.body.job_id_target == job_id)
        return await self.wait_for(None, check=check)

    async def change_presence(
        self,
        *,
        games: list[GameToDict] | None = None,
        state: PersonaState | None = None,
        flags: PersonaStateFlag = None,
        ui_mode: UIMode | None = None,
        force_kick: bool = False,
    ) -> None:
        self._connection._games = games or self._connection._games
        self._connection._state = state or self._connection._state
        self._connection._ui_mode = ui_mode or self._connection._ui_mode
        self._connection._flags = flags or self._connection._flags
        self._connection._force_kick = force_kick

        if force_kick:
            kick_msg = MsgProto(EMsg.ClientKickPlayingSession)
            log.debug("Kicking any currently playing sessions")
            await self.send_proto(kick_msg)
        if games:
            games_msg = MsgProto(EMsg.ClientGamesPlayedWithDataBlob, games_played=games)
            log.debug("Sending %r to change activity", games_msg)
            await self.send_proto(games_msg)
        if state is not None or flags:
            state_msg = MsgProto(EMsg.ClientChangeStatus, persona_state=state, persona_state_flags=flags)
            log.debug("Sending %r to change state", state_msg)
            await self.send_proto(state_msg)
        if ui_mode is not None:
            ui_mode_msg = MsgProto(EMsg.ClientCurrentUIMode, uimode=ui_mode)
            log.debug("Sending %r to change UI mode", ui_mode_msg)
            await self.send_proto(ui_mode_msg)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: steammessages_clientserver.proto
# plugin: python-betterproto
# Last updated 09/09/2021

from dataclasses import dataclass
from typing import List

import betterproto

from .base import CMsgAuthTicket, CMsgIpAddress
from .encrypted_app_ticket import EncryptedAppTicket


@dataclass(eq=False, repr=False)
class CMsgClientRegisterAuthTicketWithCm(betterproto.Message):
    protocol_version: int = betterproto.uint32_field(1)
    ticket: bytes = betterproto.bytes_field(3)
    client_instance_id: int = betterproto.uint64_field(4)


@dataclass(eq=False, repr=False)
class CMsgClientTicketAuthComplete(betterproto.Message):
    steam_id: int = betterproto.fixed64_field(1)
    game_id: int = betterproto.fixed64_field(2)
    estate: int = betterproto.uint32_field(3)
    eauth_session_response: int = betterproto.uint32_field(4)
    deprecated_ticket: bytes = betterproto.bytes_field(5)
    ticket_crc: int = betterproto.uint32_field(6)
    ticket_sequence: int = betterproto.uint32_field(7)
    owner_steam_id: int = betterproto.fixed64_field(8)


@dataclass(eq=False, repr=False)
class CMsgClientCmList(betterproto.Message):
    cm_addresses: List[int] = betterproto.uint32_field(1)
    cm_ports: List[int] = betterproto.uint32_field(2)
    cm_websocket_addresses: List[str] = betterproto.string_field(3)
    percent_default_to_websocket: int = betterproto.uint32_field(4)


@dataclass(eq=False, repr=False)
class CMsgClientP2PConnectionInfo(betterproto.Message):
    steam_id_dest: int = betterproto.fixed64_field(1)
    steam_id_src: int = betterproto.fixed64_field(2)
    app_id: int = betterproto.uint32_field(3)
    candidate: bytes = betterproto.bytes_field(4)
    legacy_connection_id_src: int = betterproto.fixed64_field(5)
    rendezvous: bytes = betterproto.bytes_field(6)


@dataclass(eq=False, repr=False)
class CMsgClientP2PConnectionFailInfo(betterproto.Message):
    steam_id_dest: int = betterproto.fixed64_field(1)
    steam_id_src: int = betterproto.fixed64_field(2)
    app_id: int = betterproto.uint32_field(3)
    ep2_p_session_error: int = betterproto.uint32_field(4)
    connection_id_dest: int = betterproto.fixed64_field(5)
    close_reason: int = betterproto.uint32_field(7)
    close_message: str = betterproto.string_field(8)


@dataclass(eq=False, repr=False)
class CMsgClientNetworkingCertRequest(betterproto.Message):
    key_data: bytes = betterproto.bytes_field(2)
    app_id: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientNetworkingCertReply(betterproto.Message):
    cert: bytes = betterproto.bytes_field(4)
    ca_key_id: int = betterproto.fixed64_field(5)
    ca_signature: bytes = betterproto.bytes_field(6)


@dataclass(eq=False, repr=False)
class CMsgClientNetworkingMobileCertRequest(betterproto.Message):
    app_id: int = betterproto.uint32_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientNetworkingMobileCertReply(betterproto.Message):
    encoded_cert: str = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientGetAppOwnershipTicket(betterproto.Message):
    app_id: int = betterproto.uint32_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientGetAppOwnershipTicketResponse(betterproto.Message):
    eresult: int = betterproto.uint32_field(1)
    app_id: int = betterproto.uint32_field(2)
    ticket: bytes = betterproto.bytes_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientSessionToken(betterproto.Message):
    token: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientGameConnectTokens(betterproto.Message):
    max_tokens_to_keep: int = betterproto.uint32_field(1)
    tokens: List[bytes] = betterproto.bytes_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientGamesPlayed(betterproto.Message):
    games_played: List["CMsgClientGamesPlayedGamePlayed"] = betterproto.message_field(1)
    client_os_type: int = betterproto.uint32_field(2)
    cloud_gaming_platform: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientGamesPlayedGamePlayed(betterproto.Message):
    steam_id_gs: int = betterproto.uint64_field(1)
    game_id: int = betterproto.fixed64_field(2)
    deprecated_game_ip_address: int = betterproto.uint32_field(3)
    game_port: int = betterproto.uint32_field(4)
    is_secure: bool = betterproto.bool_field(5)
    token: bytes = betterproto.bytes_field(6)
    game_extra_info: str = betterproto.string_field(7)
    game_data_blob: bytes = betterproto.bytes_field(8)
    process_id: int = betterproto.uint32_field(9)
    streaming_provider_id: int = betterproto.uint32_field(10)
    game_flags: int = betterproto.uint32_field(11)
    owner_id: int = betterproto.uint32_field(12)
    vr_hmd_vendor: str = betterproto.string_field(13)
    vr_hmd_model: str = betterproto.string_field(14)
    launch_option_type: int = betterproto.uint32_field(15)
    primary_controller_type: int = betterproto.int32_field(16)
    primary_steam_controller_serial: str = betterproto.string_field(17)
    total_steam_controller_count: int = betterproto.uint32_field(18)
    total_non_steam_controller_count: int = betterproto.uint32_field(19)
    controller_workshop_file_id: int = betterproto.uint64_field(20)
    launch_source: int = betterproto.uint32_field(21)
    vr_hmd_runtime: int = betterproto.uint32_field(22)
    game_ip_address: CMsgIpAddress = betterproto.message_field(23)
    controller_connection_type: int = betterproto.uint32_field(24)


@dataclass(eq=False, repr=False)
class CMsgGsApprove(betterproto.Message):
    steam_id: int = betterproto.fixed64_field(1)
    owner_steam_id: int = betterproto.fixed64_field(2)


@dataclass(eq=False, repr=False)
class CMsgGsDeny(betterproto.Message):
    steam_id: int = betterproto.fixed64_field(1)
    edeny_reason: int = betterproto.int32_field(2)
    deny_string: str = betterproto.string_field(3)


@dataclass(eq=False, repr=False)
class CMsgGsKick(betterproto.Message):
    steam_id: int = betterproto.fixed64_field(1)
    edeny_reason: int = betterproto.int32_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientAuthList(betterproto.Message):
    tokens_left: int = betterproto.uint32_field(1)
    last_request_seq: int = betterproto.uint32_field(2)
    last_request_seq_from_server: int = betterproto.uint32_field(3)
    tickets: List[CMsgAuthTicket] = betterproto.message_field(4)
    app_ids: List[int] = betterproto.uint32_field(5)
    message_sequence: int = betterproto.uint32_field(6)


@dataclass(eq=False, repr=False)
class CMsgClientAuthListAck(betterproto.Message):
    ticket_crc: List[int] = betterproto.uint32_field(1)
    app_ids: List[int] = betterproto.uint32_field(2)
    message_sequence: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientLicenseList(betterproto.Message):
    eresult: int = betterproto.int32_field(1)
    licenses: List["CMsgClientLicenseListLicense"] = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientLicenseListLicense(betterproto.Message):
    package_id: int = betterproto.uint32_field(1)
    time_created: int = betterproto.fixed32_field(2)
    time_next_process: int = betterproto.fixed32_field(3)
    minute_limit: int = betterproto.int32_field(4)
    minutes_used: int = betterproto.int32_field(5)
    payment_method: int = betterproto.uint32_field(6)
    flags: int = betterproto.uint32_field(7)
    purchase_country_code: str = betterproto.string_field(8)
    license_type: int = betterproto.uint32_field(9)
    territory_code: int = betterproto.int32_field(10)
    change_number: int = betterproto.int32_field(11)
    owner_id: int = betterproto.uint32_field(12)
    initial_period: int = betterproto.uint32_field(13)
    initial_time_unit: int = betterproto.uint32_field(14)
    renewal_period: int = betterproto.uint32_field(15)
    renewal_time_unit: int = betterproto.uint32_field(16)
    access_token: int = betterproto.uint64_field(17)
    master_package_id: int = betterproto.uint32_field(18)


@dataclass(eq=False, repr=False)
class CMsgClientIsLimitedAccount(betterproto.Message):
    bis_limited_account: bool = betterproto.bool_field(1)
    bis_community_banned: bool = betterproto.bool_field(2)
    bis_locked_account: bool = betterproto.bool_field(3)
    bis_limited_account_allowed_to_invite_friends: bool = betterproto.bool_field(4)


@dataclass(eq=False, repr=False)
class CMsgClientRequestedClientStats(betterproto.Message):
    stats_to_send: List["CMsgClientRequestedClientStatsStatsToSend"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientRequestedClientStatsStatsToSend(betterproto.Message):
    client_stat: int = betterproto.uint32_field(1)
    stat_aggregate_method: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientStat2(betterproto.Message):
    stat_detail: List["CMsgClientStat2StatDetail"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientStat2StatDetail(betterproto.Message):
    client_stat: int = betterproto.uint32_field(1)
    ll_value: int = betterproto.int64_field(2)
    time_of_day: int = betterproto.uint32_field(3)
    cell_id: int = betterproto.uint32_field(4)
    depot_id: int = betterproto.uint32_field(5)
    app_id: int = betterproto.uint32_field(6)


@dataclass(eq=False, repr=False)
class CMsgClientInviteToGame(betterproto.Message):
    steam_id_dest: int = betterproto.fixed64_field(1)
    steam_id_src: int = betterproto.fixed64_field(2)
    connect_string: str = betterproto.string_field(3)
    remote_play: str = betterproto.string_field(4)


@dataclass(eq=False, repr=False)
class CMsgClientChatInvite(betterproto.Message):
    steam_id_invited: int = betterproto.fixed64_field(1)
    steam_id_chat: int = betterproto.fixed64_field(2)
    steam_id_patron: int = betterproto.fixed64_field(3)
    chatroom_type: int = betterproto.int32_field(4)
    steam_id_friend_chat: int = betterproto.fixed64_field(5)
    chat_name: str = betterproto.string_field(6)
    game_id: int = betterproto.fixed64_field(7)


@dataclass(eq=False, repr=False)
class CMsgClientConnectionStats(betterproto.Message):
    stats_logon: "CMsgClientConnectionStatsStatsLogon" = betterproto.message_field(1)
    stats_vconn: "CMsgClientConnectionStatsStatsVConn" = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientConnectionStatsStatsLogon(betterproto.Message):
    connect_attempts: int = betterproto.int32_field(1)
    connect_successes: int = betterproto.int32_field(2)
    connect_failures: int = betterproto.int32_field(3)
    connections_dropped: int = betterproto.int32_field(4)
    seconds_running: int = betterproto.uint32_field(5)
    msec_tologonthistime: int = betterproto.uint32_field(6)
    count_bad_cms: int = betterproto.uint32_field(7)


@dataclass(eq=False, repr=False)
class CMsgClientConnectionStatsStatsUdp(betterproto.Message):
    pkts_sent: int = betterproto.uint64_field(1)
    bytes_sent: int = betterproto.uint64_field(2)
    pkts_recv: int = betterproto.uint64_field(3)
    pkts_processed: int = betterproto.uint64_field(4)
    bytes_recv: int = betterproto.uint64_field(5)


@dataclass(eq=False, repr=False)
class CMsgClientConnectionStatsStatsVConn(betterproto.Message):
    connections_udp: int = betterproto.uint32_field(1)
    connections_tcp: int = betterproto.uint32_field(2)
    stats_udp: "CMsgClientConnectionStatsStatsUdp" = betterproto.message_field(3)
    pkts_abandoned: int = betterproto.uint64_field(4)
    conn_req_received: int = betterproto.uint64_field(5)
    pkts_resent: int = betterproto.uint64_field(6)
    msgs_sent: int = betterproto.uint64_field(7)
    msgs_sent_failed: int = betterproto.uint64_field(8)
    msgs_recv: int = betterproto.uint64_field(9)
    datagrams_sent: int = betterproto.uint64_field(10)
    datagrams_recv: int = betterproto.uint64_field(11)
    bad_pkts_recv: int = betterproto.uint64_field(12)
    unknown_conn_pkts_recv: int = betterproto.uint64_field(13)
    missed_pkts_recv: int = betterproto.uint64_field(14)
    dup_pkts_recv: int = betterproto.uint64_field(15)
    failed_connect_challenges: int = betterproto.uint64_field(16)
    micro_sec_avg_latency: int = betterproto.uint32_field(17)
    micro_sec_min_latency: int = betterproto.uint32_field(18)
    micro_sec_max_latency: int = betterproto.uint32_field(19)
    mem_pool_msg_in_use: int = betterproto.uint32_field(20)


@dataclass(eq=False, repr=False)
class CMsgClientServersAvailable(betterproto.Message):
    server_types_available: List["CMsgClientServersAvailableServerTypesAvailable"] = betterproto.message_field(1)
    server_type_for_auth_services: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientServersAvailableServerTypesAvailable(betterproto.Message):
    server: int = betterproto.uint32_field(1)
    changed: bool = betterproto.bool_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientReportOverlayDetourFailure(betterproto.Message):
    failure_strings: List[str] = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientRequestEncryptedAppTicket(betterproto.Message):
    app_id: int = betterproto.uint32_field(1)
    userdata: bytes = betterproto.bytes_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientRequestEncryptedAppTicketResponse(betterproto.Message):
    app_id: int = betterproto.uint32_field(1)
    eresult: int = betterproto.int32_field(2)
    encrypted_app_ticket: EncryptedAppTicket = betterproto.message_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientWalletInfoUpdate(betterproto.Message):
    has_wallet: bool = betterproto.bool_field(1)
    balance: int = betterproto.int32_field(2)
    currency: int = betterproto.int32_field(3)
    balance_delayed: int = betterproto.int32_field(4)
    balance64: int = betterproto.int64_field(5)
    balance64_delayed: int = betterproto.int64_field(6)
    realm: int = betterproto.int32_field(7)


@dataclass(eq=False, repr=False)
class CMsgClientAmGetClanOfficers(betterproto.Message):
    steamid_clan: int = betterproto.fixed64_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientAmGetClanOfficersResponse(betterproto.Message):
    eresult: int = betterproto.int32_field(1)
    steamid_clan: int = betterproto.fixed64_field(2)
    officer_count: int = betterproto.int32_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientAmGetPersonaNameHistory(betterproto.Message):
    id_count: int = betterproto.int32_field(1)
    ids: List["CMsgClientAmGetPersonaNameHistoryIdInstance"] = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientAmGetPersonaNameHistoryIdInstance(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientAmGetPersonaNameHistoryResponse(betterproto.Message):
    responses: List["CMsgClientAmGetPersonaNameHistoryResponseNameTableInstance"] = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientAmGetPersonaNameHistoryResponseNameTableInstance(betterproto.Message):
    eresult: int = betterproto.int32_field(1)
    steamid: int = betterproto.fixed64_field(2)
    names: List["CMsgClientAmGetPersonaNameHistoryResponseNameTableInstanceNameInstance"] = betterproto.message_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientAmGetPersonaNameHistoryResponseNameTableInstanceNameInstance(betterproto.Message):
    name_since: int = betterproto.fixed32_field(1)
    name: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientDeregisterWithServer(betterproto.Message):
    eservertype: int = betterproto.uint32_field(1)
    app_id: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientClanState(betterproto.Message):
    steamid_clan: int = betterproto.fixed64_field(1)
    clan_account_flags: int = betterproto.uint32_field(3)
    name_info: "CMsgClientClanStateNameInfo" = betterproto.message_field(4)
    user_counts: "CMsgClientClanStateUserCounts" = betterproto.message_field(5)
    events: List["CMsgClientClanStateEvent"] = betterproto.message_field(6)
    announcements: List["CMsgClientClanStateEvent"] = betterproto.message_field(7)
    chat_room_private: bool = betterproto.bool_field(8)


@dataclass(eq=False, repr=False)
class CMsgClientClanStateNameInfo(betterproto.Message):
    clan_name: str = betterproto.string_field(1)
    sha_avatar: bytes = betterproto.bytes_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientClanStateUserCounts(betterproto.Message):
    members: int = betterproto.uint32_field(1)
    online: int = betterproto.uint32_field(2)
    chatting: int = betterproto.uint32_field(3)
    in_game: int = betterproto.uint32_field(4)
    chat_room_members: int = betterproto.uint32_field(5)


@dataclass(eq=False, repr=False)
class CMsgClientClanStateEvent(betterproto.Message):
    gid: int = betterproto.fixed64_field(1)
    event_time: int = betterproto.uint32_field(2)
    headline: str = betterproto.string_field(3)
    game_id: int = betterproto.fixed64_field(4)
    just_posted: bool = betterproto.bool_field(5)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: steammessages_chat.proto
# plugin: python-betterproto
# Last updated 09/09/2021

from dataclasses import dataclass
from typing import List

import betterproto

from .friends import CMsgClientPersonaStateFriend


class EChatRoomJoinState(betterproto.Enum):
    Default = 0
    NONE = 1
    Joined = 2
    TestInvalid = 99


class EChatRoomGroupRank(betterproto.Enum):
    Default = 0
    Viewer = 10
    Guest = 15
    Member = 20
    Moderator = 30
    Officer = 40
    Owner = 50
    TestInvalid = 99


class EChatRoomNotificationLevel(betterproto.Enum):
    Invalid = 0
    NONE = 1
    MentionMe = 2
    MentionAll = 3
    AllMessages = 4


class EChatRoomServerMessage(betterproto.Enum):
    Invalid = 0
    RenameChatRoom = 1
    Joined = 2
    Parted = 3
    Kicked = 4
    Invited = 5
    InviteDismissed = 8
    ChatRoomTaglineChanged = 9
    ChatRoomAvatarChanged = 10
    AppCustom = 11


class EChatRoomMessageReactionType(betterproto.Enum):
    Invalid = 0
    Emoticon = 1
    Sticker = 2


class EChatRoomMemberStateChange(betterproto.Enum):
    Invalid = 0
    Joined = 1
    Parted = 2
    Kicked = 3
    Invited = 4
    RankChanged = 7
    InviteDismissed = 8
    Muted = 9
    Banned = 10
    RolesChanged = 12


@dataclass(eq=False, repr=False)
class RequestFriendPersonaStatesRequest(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class RequestFriendPersonaStatesResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class CreateChatRoomGroupRequest(betterproto.Message):
    steamid_partner: int = betterproto.fixed64_field(1)
    steamid_invited: int = betterproto.fixed64_field(2)
    name: str = betterproto.string_field(3)
    steamid_invitees: List[int] = betterproto.fixed64_field(4)
    watching_broadcast_accountid: int = betterproto.uint32_field(6)
    watching_broadcast_channel_id: int = betterproto.uint64_field(7)


@dataclass(eq=False, repr=False)
class Role(betterproto.Message):
    role_id: int = betterproto.uint64_field(1)
    name: str = betterproto.string_field(2)
    ordinal: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class RoleActions(betterproto.Message):
    role_id: int = betterproto.uint64_field(1)
    can_create_rename_delete_channel: bool = betterproto.bool_field(2)
    can_kick: bool = betterproto.bool_field(3)
    can_ban: bool = betterproto.bool_field(4)
    can_invite: bool = betterproto.bool_field(5)
    can_change_tagline_avatar_name: bool = betterproto.bool_field(6)
    can_chat: bool = betterproto.bool_field(7)
    can_view_history: bool = betterproto.bool_field(8)
    can_change_group_roles: bool = betterproto.bool_field(9)
    can_change_user_roles: bool = betterproto.bool_field(10)
    can_mention_all: bool = betterproto.bool_field(11)
    can_set_watching_broadcast: bool = betterproto.bool_field(12)


@dataclass(eq=False, repr=False)
class PartyBeacon(betterproto.Message):
    app_id: int = betterproto.uint32_field(1)
    steamid_owner: int = betterproto.fixed64_field(2)
    beacon_id: int = betterproto.fixed64_field(3)
    game_metadata: str = betterproto.string_field(4)


@dataclass(eq=False, repr=False)
class GroupHeaderState(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_name: str = betterproto.string_field(2)
    clanid: int = betterproto.uint32_field(13)
    accountid_owner: int = betterproto.uint32_field(14)
    appid: int = betterproto.uint32_field(21)
    tagline: str = betterproto.string_field(15)
    avatar_sha: bytes = betterproto.bytes_field(16)
    default_role_id: int = betterproto.uint64_field(17)
    roles: List["Role"] = betterproto.message_field(18)
    role_actions: List["RoleActions"] = betterproto.message_field(19)
    watching_broadcast_accountid: int = betterproto.uint32_field(20)
    party_beacons: List["PartyBeacon"] = betterproto.message_field(22)
    watching_broadcast_channel_id: int = betterproto.uint64_field(23)
    active_minigame_id: int = betterproto.uint64_field(24)
    avatar_ugc_url: str = betterproto.string_field(25)
    disabled: bool = betterproto.bool_field(26)


@dataclass(eq=False, repr=False)
class Member(betterproto.Message):
    accountid: int = betterproto.uint32_field(1)
    state: "EChatRoomJoinState" = betterproto.enum_field(3)
    rank: "EChatRoomGroupRank" = betterproto.enum_field(4)
    time_kick_expire: int = betterproto.uint32_field(6)
    role_ids: List[int] = betterproto.uint64_field(7)


@dataclass(eq=False, repr=False)
class State(betterproto.Message):
    chat_id: int = betterproto.uint64_field(1)
    chat_name: str = betterproto.string_field(2)
    voice_allowed: bool = betterproto.bool_field(3)
    members_in_voice: List[int] = betterproto.uint32_field(4)
    time_last_message: int = betterproto.uint32_field(5)
    sort_order: int = betterproto.uint32_field(6)
    last_message: str = betterproto.string_field(7)
    accountid_last_message: int = betterproto.uint32_field(8)


@dataclass(eq=False, repr=False)
class GroupState(betterproto.Message):
    header_state: "GroupHeaderState" = betterproto.message_field(1)
    members: List["Member"] = betterproto.message_field(2)
    default_chat_id: int = betterproto.uint64_field(4)
    chat_rooms: List["State"] = betterproto.message_field(5)
    kicked: List["Member"] = betterproto.message_field(7)


@dataclass(eq=False, repr=False)
class ChatRoomState(betterproto.Message):
    chat_id: int = betterproto.uint64_field(1)
    time_joined: int = betterproto.uint32_field(2)
    time_last_ack: int = betterproto.uint32_field(3)
    desktop_notification_level: "EChatRoomNotificationLevel" = betterproto.enum_field(4)
    mobile_notification_level: "EChatRoomNotificationLevel" = betterproto.enum_field(5)
    time_last_mention: int = betterproto.uint32_field(6)
    unread_indicator_muted: bool = betterproto.bool_field(7)
    time_first_unread: int = betterproto.uint32_field(8)


@dataclass(eq=False, repr=False)
class ChatRoomGroupState(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    time_joined: int = betterproto.uint32_field(2)
    user_chat_room_state: List["ChatRoomState"] = betterproto.message_field(3)
    desktop_notification_level: "EChatRoomNotificationLevel" = betterproto.enum_field(4)
    mobile_notification_level: "EChatRoomNotificationLevel" = betterproto.enum_field(5)
    time_last_group_ack: int = betterproto.uint32_field(6)
    unread_indicator_muted: bool = betterproto.bool_field(7)


@dataclass(eq=False, repr=False)
class CreateChatRoomGroupResponse(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    state: "GroupState" = betterproto.message_field(2)
    user_chat_state: "ChatRoomGroupState" = betterproto.message_field(3)


@dataclass(eq=False, repr=False)
class SaveChatRoomGroupRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    name: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class SaveChatRoomGroupResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class RenameChatRoomGroupRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    name: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class RenameChatRoomGroupResponse(betterproto.Message):
    name: str = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class SetChatRoomGroupTaglineRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    tagline: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class SetChatRoomGroupTaglineResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class SetChatRoomGroupAvatarRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    avatar_sha: bytes = betterproto.bytes_field(2)


@dataclass(eq=False, repr=False)
class SetChatRoomGroupAvatarResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class SetChatRoomGroupWatchingBroadcastRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    watching_broadcast_accountid: int = betterproto.uint32_field(2)
    watching_broadcast_channel_id: int = betterproto.uint64_field(3)


@dataclass(eq=False, repr=False)
class SetChatRoomGroupWatchingBroadcastResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class JoinMiniGameForChatRoomGroupRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)


@dataclass(eq=False, repr=False)
class JoinMiniGameForChatRoomGroupResponse(betterproto.Message):
    minigame_id: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class EndMiniGameForChatRoomGroupRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    minigame_id: int = betterproto.uint64_field(3)


@dataclass(eq=False, repr=False)
class EndMiniGameForChatRoomGroupResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class MuteUserRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    steamid: int = betterproto.fixed64_field(2)
    expiration: int = betterproto.int32_field(3)


@dataclass(eq=False, repr=False)
class MuteUserResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class KickUserRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    steamid: int = betterproto.fixed64_field(2)
    expiration: int = betterproto.int32_field(3)


@dataclass(eq=False, repr=False)
class KickUserResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class SetUserBanStateRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    steamid: int = betterproto.fixed64_field(2)
    ban_state: bool = betterproto.bool_field(3)


@dataclass(eq=False, repr=False)
class SetUserBanStateResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class RevokeInviteRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    steamid: int = betterproto.fixed64_field(2)


@dataclass(eq=False, repr=False)
class RevokeInviteResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class CreateRoleRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    name: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class CreateRoleResponse(betterproto.Message):
    actions: "RoleActions" = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class GetRolesRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class GetRolesResponse(betterproto.Message):
    roles: List["Role"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class RenameRoleRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    role_id: int = betterproto.uint64_field(2)
    name: str = betterproto.string_field(3)


@dataclass(eq=False, repr=False)
class RenameRoleResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class ReorderRoleRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    role_id: int = betterproto.uint64_field(2)
    ordinal: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class ReorderRoleResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class DeleteRoleRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    role_id: int = betterproto.uint64_field(2)


@dataclass(eq=False, repr=False)
class DeleteRoleResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetRoleActionsRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    role_id: int = betterproto.uint64_field(2)


@dataclass(eq=False, repr=False)
class GetRoleActionsResponse(betterproto.Message):
    actions: List["RoleActions"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class ReplaceRoleActionsRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    role_id: int = betterproto.uint64_field(2)
    actions: "RoleActions" = betterproto.message_field(4)


@dataclass(eq=False, repr=False)
class ReplaceRoleActionsResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class AddRoleToUserRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    role_id: int = betterproto.uint64_field(3)
    steamid: int = betterproto.fixed64_field(4)


@dataclass(eq=False, repr=False)
class AddRoleToUserResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetRolesForUserRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    steamid: int = betterproto.fixed64_field(3)


@dataclass(eq=False, repr=False)
class GetRolesForUserResponse(betterproto.Message):
    role_ids: List[int] = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class DeleteRoleFromUserRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    role_id: int = betterproto.uint64_field(3)
    steamid: int = betterproto.fixed64_field(4)


@dataclass(eq=False, repr=False)
class DeleteRoleFromUserResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class JoinChatRoomGroupRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    invite_code: str = betterproto.string_field(2)
    chat_id: int = betterproto.uint64_field(3)


@dataclass(eq=False, repr=False)
class JoinChatRoomGroupResponse(betterproto.Message):
    state: "GroupState" = betterproto.message_field(1)
    user_chat_state: "ChatRoomGroupState" = betterproto.message_field(3)
    join_chat_id: int = betterproto.uint64_field(4)
    time_expire: int = betterproto.uint32_field(5)


@dataclass(eq=False, repr=False)
class InviteFriendToChatRoomGroupRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    steamid: int = betterproto.fixed64_field(2)
    chat_id: int = betterproto.uint64_field(3)
    skip_friendsui_check: bool = betterproto.bool_field(4)


@dataclass(eq=False, repr=False)
class InviteFriendToChatRoomGroupResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class LeaveChatRoomGroupRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class LeaveChatRoomGroupResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class CreateChatRoomRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    name: str = betterproto.string_field(2)
    allow_voice: bool = betterproto.bool_field(3)


@dataclass(eq=False, repr=False)
class CreateChatRoomResponse(betterproto.Message):
    chat_room: "State" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class DeleteChatRoomRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)


@dataclass(eq=False, repr=False)
class DeleteChatRoomResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class RenameChatRoomRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    name: str = betterproto.string_field(3)


@dataclass(eq=False, repr=False)
class RenameChatRoomResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class ReorderChatRoomRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    move_after_chat_id: int = betterproto.uint64_field(3)


@dataclass(eq=False, repr=False)
class ReorderChatRoomResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class SendChatMessageRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    message: str = betterproto.string_field(3)
    echo_to_sender: bool = betterproto.bool_field(4)


@dataclass(eq=False, repr=False)
class SendChatMessageResponse(betterproto.Message):
    modified_message: str = betterproto.string_field(1)
    server_timestamp: int = betterproto.uint32_field(2)
    ordinal: int = betterproto.uint32_field(3)
    message_without_bb_code: str = betterproto.string_field(4)


@dataclass(eq=False, repr=False)
class JoinVoiceChatRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)


@dataclass(eq=False, repr=False)
class JoinVoiceChatResponse(betterproto.Message):
    voice_chatid: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class LeaveVoiceChatRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)


@dataclass(eq=False, repr=False)
class LeaveVoiceChatResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetMessageHistoryRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    last_time: int = betterproto.uint32_field(3)
    last_ordinal: int = betterproto.uint32_field(4)
    start_time: int = betterproto.uint32_field(5)
    start_ordinal: int = betterproto.uint32_field(6)
    max_count: int = betterproto.uint32_field(7)


@dataclass(eq=False, repr=False)
class ServerMessage(betterproto.Message):
    message: "EChatRoomServerMessage" = betterproto.enum_field(1)
    string_param: str = betterproto.string_field(2)
    accountid_param: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class GetMessageHistoryResponse(betterproto.Message):
    messages: List["GetMessageHistoryResponseChatMessage"] = betterproto.message_field(1)
    more_available: bool = betterproto.bool_field(4)


@dataclass(eq=False, repr=False)
class GetMessageHistoryResponseChatMessage(betterproto.Message):
    sender: int = betterproto.uint32_field(1)
    server_timestamp: int = betterproto.uint32_field(2)
    message: str = betterproto.string_field(3)
    ordinal: int = betterproto.uint32_field(4)
    server_message: "ServerMessage" = betterproto.message_field(5)
    deleted: bool = betterproto.bool_field(6)
    reactions: List["GetMessageHistoryResponseChatMessageMessageReaction"] = betterproto.message_field(7)


@dataclass(eq=False, repr=False)
class GetMessageHistoryResponseChatMessageMessageReaction(betterproto.Message):
    reaction_type: "EChatRoomMessageReactionType" = betterproto.enum_field(1)
    reaction: str = betterproto.string_field(2)
    num_reactors: int = betterproto.uint32_field(3)
    has_user_reacted: bool = betterproto.bool_field(4)


@dataclass(eq=False, repr=False)
class GetMyChatRoomGroupsRequest(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetChatRoomGroupSummaryResponse(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_group_name: str = betterproto.string_field(2)
    active_member_count: int = betterproto.uint32_field(3)
    active_voice_member_count: int = betterproto.uint32_field(4)
    default_chat_id: int = betterproto.uint64_field(5)
    chat_rooms: List["State"] = betterproto.message_field(6)
    clanid: int = betterproto.uint32_field(7)
    chat_group_tagline: str = betterproto.string_field(8)
    accountid_owner: int = betterproto.uint32_field(9)
    top_members: List[int] = betterproto.uint32_field(10)
    chat_group_avatar_sha: bytes = betterproto.bytes_field(11)
    rank: "EChatRoomGroupRank" = betterproto.enum_field(12)
    default_role_id: int = betterproto.uint64_field(13)
    role_ids: List[int] = betterproto.uint64_field(14)
    role_actions: List["RoleActions"] = betterproto.message_field(15)
    watching_broadcast_accountid: int = betterproto.uint32_field(16)
    appid: int = betterproto.uint32_field(17)
    party_beacons: List["PartyBeacon"] = betterproto.message_field(18)
    watching_broadcast_channel_id: int = betterproto.uint64_field(19)
    active_minigame_id: int = betterproto.uint64_field(20)
    avatar_ugc_url: str = betterproto.string_field(21)
    disabled: bool = betterproto.bool_field(22)


@dataclass(eq=False, repr=False)
class SummaryPair(betterproto.Message):
    user_chat_group_state: "ChatRoomGroupState" = betterproto.message_field(1)
    group_summary: "GetChatRoomGroupSummaryResponse" = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class GetMyChatRoomGroupsResponse(betterproto.Message):
    chat_room_groups: List["SummaryPair"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetChatRoomGroupStateRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class GetChatRoomGroupStateResponse(betterproto.Message):
    state: "GroupState" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetChatRoomGroupSummaryRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class SetAppChatRoomGroupForceActiveRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    requesting_app_id: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class SetAppChatRoomGroupForceActiveResponse(betterproto.Message):
    result: int = betterproto.uint32_field(1)
    accounts_in_channel: List[int] = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class SetAppChatRoomGroupStopForceActiveNotification(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    requesting_app_id: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class AckChatMessageNotification(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    timestamp: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class CreateInviteLinkRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    seconds_valid: int = betterproto.uint32_field(2)
    chat_id: int = betterproto.uint64_field(3)


@dataclass(eq=False, repr=False)
class CreateInviteLinkResponse(betterproto.Message):
    invite_code: str = betterproto.string_field(1)
    seconds_valid: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class GetInviteLinkInfoRequest(betterproto.Message):
    invite_code: str = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class GetInviteLinkInfoResponse(betterproto.Message):
    steamid_sender: int = betterproto.fixed64_field(3)
    time_expires: int = betterproto.uint32_field(4)
    chat_id: int = betterproto.uint64_field(6)
    group_summary: "GetChatRoomGroupSummaryResponse" = betterproto.message_field(8)
    user_chat_group_state: "ChatRoomGroupState" = betterproto.message_field(9)
    time_kick_expire: int = betterproto.uint32_field(10)
    banned: bool = betterproto.bool_field(11)


@dataclass(eq=False, repr=False)
class GetInviteInfoRequest(betterproto.Message):
    steamid_invitee: int = betterproto.fixed64_field(1)
    chat_group_id: int = betterproto.uint64_field(2)
    chat_id: int = betterproto.uint64_field(3)
    invite_code: str = betterproto.string_field(4)


@dataclass(eq=False, repr=False)
class GetInviteInfoResponse(betterproto.Message):
    group_summary: "GetChatRoomGroupSummaryResponse" = betterproto.message_field(1)
    time_kick_expire: int = betterproto.uint32_field(2)
    banned: bool = betterproto.bool_field(3)


@dataclass(eq=False, repr=False)
class GetInviteLinksForGroupRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class GetInviteLinksForGroupResponse(betterproto.Message):
    invite_links: List["GetInviteLinksForGroupResponseLinkInfo"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetInviteLinksForGroupResponseLinkInfo(betterproto.Message):
    invite_code: str = betterproto.string_field(1)
    steamid_creator: int = betterproto.fixed64_field(2)
    time_expires: int = betterproto.uint32_field(3)
    chat_id: int = betterproto.uint64_field(4)


@dataclass(eq=False, repr=False)
class GetBanListRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class GetBanListResponse(betterproto.Message):
    bans: List["GetBanListResponseBanInfo"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetBanListResponseBanInfo(betterproto.Message):
    accountid: int = betterproto.uint32_field(1)
    accountid_actor: int = betterproto.uint32_field(2)
    time_banned: int = betterproto.uint32_field(3)
    ban_reason: str = betterproto.string_field(4)


@dataclass(eq=False, repr=False)
class GetInviteListRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class GroupInvite(betterproto.Message):
    accountid: int = betterproto.uint32_field(1)
    accountid_actor: int = betterproto.uint32_field(2)
    time_invited: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class GetInviteListResponse(betterproto.Message):
    invites: List["GroupInvite"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class DeleteInviteLinkRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    invite_code: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class DeleteInviteLinkResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class SetSessionActiveChatRoomGroupsRequest(betterproto.Message):
    chat_group_ids: List[int] = betterproto.uint64_field(1)
    chat_groups_data_requested: List[int] = betterproto.uint64_field(2)
    virtualize_members_threshold: int = betterproto.int32_field(3)


@dataclass(eq=False, repr=False)
class SetSessionActiveChatRoomGroupsResponse(betterproto.Message):
    chat_states: List["GroupState"] = betterproto.message_field(1)
    virtualize_members_chat_group_ids: List[int] = betterproto.uint64_field(2)


@dataclass(eq=False, repr=False)
class SetUserChatGroupPreferencesRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_group_preferences: "SetUserChatGroupPreferencesRequestChatGroupPreferences" = betterproto.message_field(2)
    chat_room_preferences: List["SetUserChatGroupPreferencesRequestChatRoomPreferences"] = betterproto.message_field(3)


@dataclass(eq=False, repr=False)
class SetUserChatGroupPreferencesRequestChatGroupPreferences(betterproto.Message):
    desktop_notification_level: "EChatRoomNotificationLevel" = betterproto.enum_field(1)
    mobile_notification_level: "EChatRoomNotificationLevel" = betterproto.enum_field(2)
    unread_indicator_muted: bool = betterproto.bool_field(3)


@dataclass(eq=False, repr=False)
class SetUserChatGroupPreferencesRequestChatRoomPreferences(betterproto.Message):
    chat_id: int = betterproto.uint64_field(1)
    desktop_notification_level: "EChatRoomNotificationLevel" = betterproto.enum_field(2)
    mobile_notification_level: "EChatRoomNotificationLevel" = betterproto.enum_field(3)
    unread_indicator_muted: bool = betterproto.bool_field(4)


@dataclass(eq=False, repr=False)
class SetUserChatGroupPreferencesResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class DeleteChatMessagesRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    messages: List["DeleteChatMessagesRequestMessage"] = betterproto.message_field(3)


@dataclass(eq=False, repr=False)
class DeleteChatMessagesRequestMessage(betterproto.Message):
    server_timestamp: int = betterproto.uint32_field(1)
    ordinal: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class DeleteChatMessagesResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class UpdateMemberListViewNotification(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    view_id: int = betterproto.uint64_field(2)
    start: int = betterproto.int32_field(3)
    end: int = betterproto.int32_field(4)
    client_changenumber: int = betterproto.int32_field(5)
    delete_view: bool = betterproto.bool_field(6)
    persona_subscribe_accountids: List[int] = betterproto.int32_field(7)
    persona_unsubscribe_accountids: List[int] = betterproto.int32_field(8)


@dataclass(eq=False, repr=False)
class SearchMembersRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    search_id: int = betterproto.uint64_field(2)
    search_text: str = betterproto.string_field(3)
    max_results: int = betterproto.int32_field(4)


@dataclass(eq=False, repr=False)
class SearchMembersResponse(betterproto.Message):
    matching_members: List["SearchMembersResponseMemberMatch"] = betterproto.message_field(1)
    status_flags: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class SearchMembersResponseMemberMatch(betterproto.Message):
    accountid: int = betterproto.int32_field(1)
    persona: CMsgClientPersonaStateFriend = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class UpdateMessageReactionRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    server_timestamp: int = betterproto.uint32_field(3)
    ordinal: int = betterproto.uint32_field(4)
    reaction_type: "EChatRoomMessageReactionType" = betterproto.enum_field(5)
    reaction: str = betterproto.string_field(6)
    is_add: bool = betterproto.bool_field(7)


@dataclass(eq=False, repr=False)
class UpdateMessageReactionResponse(betterproto.Message):
    num_reactors: int = betterproto.uint32_field(1)


@dataclass(eq=False, repr=False)
class GetMessageReactionReactorsRequest(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    server_timestamp: int = betterproto.uint32_field(3)
    ordinal: int = betterproto.uint32_field(4)
    reaction_type: "EChatRoomMessageReactionType" = betterproto.enum_field(5)
    reaction: str = betterproto.string_field(6)
    limit: int = betterproto.uint32_field(7)


@dataclass(eq=False, repr=False)
class GetMessageReactionReactorsResponse(betterproto.Message):
    reactors: List[int] = betterproto.uint32_field(1)


@dataclass(eq=False, repr=False)
class GetClanChatRoomInfoRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    autocreate: bool = betterproto.bool_field(2)


@dataclass(eq=False, repr=False)
class GetClanChatRoomInfoResponse(betterproto.Message):
    chat_group_summary: "GetChatRoomGroupSummaryResponse" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class SetClanChatRoomPrivateRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    chat_room_private: bool = betterproto.bool_field(2)


@dataclass(eq=False, repr=False)
class SetClanChatRoomPrivateResponse(betterproto.Message):
    chat_room_private: bool = betterproto.bool_field(1)


@dataclass(eq=False, repr=False)
class Mentions(betterproto.Message):
    mention_all: bool = betterproto.bool_field(1)
    mention_here: bool = betterproto.bool_field(2)
    ids: List[int] = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class IncomingChatMessageNotification(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    steamid_sender: int = betterproto.fixed64_field(3)
    message: str = betterproto.string_field(4)
    timestamp: int = betterproto.uint32_field(5)
    mentions: "Mentions" = betterproto.message_field(6)
    ordinal: int = betterproto.uint32_field(7)
    server_message: "ServerMessage" = betterproto.message_field(8)
    message_no_bbcode: str = betterproto.string_field(9)
    chat_name: str = betterproto.string_field(10)


@dataclass(eq=False, repr=False)
class ChatMessageModifiedNotification(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    messages: List["ChatMessageModifiedNotificationChatMessage"] = betterproto.message_field(3)


@dataclass(eq=False, repr=False)
class ChatMessageModifiedNotificationChatMessage(betterproto.Message):
    server_timestamp: int = betterproto.uint32_field(1)
    ordinal: int = betterproto.uint32_field(2)
    deleted: bool = betterproto.bool_field(3)


@dataclass(eq=False, repr=False)
class MemberStateChangeNotification(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    member: "Member" = betterproto.message_field(2)
    change: "EChatRoomMemberStateChange" = betterproto.enum_field(3)


@dataclass(eq=False, repr=False)
class ChatRoomHeaderStateNotification(betterproto.Message):
    header_state: "GroupHeaderState" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class ChatRoomGroupRoomsChangeNotification(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    default_chat_id: int = betterproto.uint64_field(2)
    chat_rooms: List["State"] = betterproto.message_field(3)


@dataclass(eq=False, repr=False)
class NotifyShouldRejoinChatRoomVoiceChatNotification(betterproto.Message):
    chat_id: int = betterproto.uint64_field(1)
    chat_group_id: int = betterproto.uint64_field(2)


@dataclass(eq=False, repr=False)
class NotifyChatGroupUserStateChangedNotification(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    user_chat_group_state: "ChatRoomGroupState" = betterproto.message_field(2)
    group_summary: "GetChatRoomGroupSummaryResponse" = betterproto.message_field(3)
    user_action: "EChatRoomMemberStateChange" = betterproto.enum_field(4)


@dataclass(eq=False, repr=False)
class NotifyChatRoomDisconnectNotification(betterproto.Message):
    chat_group_ids: List[int] = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class MemberListView(betterproto.Message):
    start: int = betterproto.int32_field(3)
    end: int = betterproto.int32_field(4)
    total_count: int = betterproto.int32_field(5)
    client_changenumber: int = betterproto.int32_field(6)
    server_changenumber: int = betterproto.int32_field(7)


@dataclass(eq=False, repr=False)
class MemberSummaryCounts(betterproto.Message):
    ingame: int = betterproto.int32_field(1)
    online: int = betterproto.int32_field(2)
    offline: int = betterproto.int32_field(3)


@dataclass(eq=False, repr=False)
class MemberListViewUpdatedNotification(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    view_id: int = betterproto.uint64_field(2)
    view: "MemberListView" = betterproto.message_field(3)
    members: List["MemberListViewUpdatedNotificationMemberListViewEntry"] = betterproto.message_field(4)
    status_flags: int = betterproto.uint32_field(5)
    member_summary: "MemberSummaryCounts" = betterproto.message_field(6)
    subscribed_personas: List[CMsgClientPersonaStateFriend] = betterproto.message_field(7)


@dataclass(eq=False, repr=False)
class MemberListViewUpdatedNotificationMemberListViewEntry(betterproto.Message):
    rank: int = betterproto.int32_field(1)
    accountid: int = betterproto.uint32_field(2)
    persona: CMsgClientPersonaStateFriend = betterproto.message_field(3)


@dataclass(eq=False, repr=False)
class MessageReactionNotification(betterproto.Message):
    chat_group_id: int = betterproto.uint64_field(1)
    chat_id: int = betterproto.uint64_field(2)
    server_timestamp: int = betterproto.uint32_field(3)
    ordinal: int = betterproto.uint32_field(4)
    reactor: int = betterproto.fixed64_field(5)
    reaction_type: "EChatRoomMessageReactionType" = betterproto.enum_field(6)
    reaction: str = betterproto.string_field(7)
    is_add: bool = betterproto.bool_field(8)


@dataclass(eq=False, repr=False)
class UsabilityClientUsabilityMetricsNotification(betterproto.Message):
    metrics_run_id: int = betterproto.uint32_field(1)
    client_build: int = betterproto.uint32_field(2)
    metrics_version: int = betterproto.uint32_field(3)
    in_web: bool = betterproto.bool_field(4)
    settings: "UsabilityClientUsabilityMetricsNotificationSettings" = betterproto.message_field(10)
    voice_settings: "UsabilityClientUsabilityMetricsNotificationVoiceSettings" = betterproto.message_field(11)
    ui_state: "UsabilityClientUsabilityMetricsNotificationUiState" = betterproto.message_field(12)
    metrics: "UsabilityClientUsabilityMetricsNotificationMetrics" = betterproto.message_field(13)


@dataclass(eq=False, repr=False)
class UsabilityClientUsabilityMetricsNotificationSettings(betterproto.Message):
    notifications_show_ingame: bool = betterproto.bool_field(1)
    notifications_show_online: bool = betterproto.bool_field(2)
    notifications_show_message: bool = betterproto.bool_field(3)
    notifications_events_and_announcements: bool = betterproto.bool_field(4)
    sounds_play_ingame: bool = betterproto.bool_field(5)
    sounds_play_online: bool = betterproto.bool_field(6)
    sounds_play_message: bool = betterproto.bool_field(7)
    sounds_events_and_announcements: bool = betterproto.bool_field(8)
    always_new_chat_window: bool = betterproto.bool_field(9)
    force_alphabetic_friend_sorting: bool = betterproto.bool_field(10)
    chat_flash_mode: int = betterproto.int32_field(11)
    remember_open_chats: bool = betterproto.bool_field(12)
    compact_quick_access: bool = betterproto.bool_field(13)
    compact_friends_list: bool = betterproto.bool_field(14)
    notifications_show_chat_room_notification: bool = betterproto.bool_field(15)
    sounds_play_chat_room_notification: bool = betterproto.bool_field(16)
    hide_offline_friends_in_tag_groups: bool = betterproto.bool_field(17)
    hide_categorized_friends: bool = betterproto.bool_field(18)
    categorize_in_game_friends_by_game: bool = betterproto.bool_field(19)
    chat_font_size: int = betterproto.int32_field(20)
    use24_hour_clock: bool = betterproto.bool_field(21)
    do_not_disturb_mode: bool = betterproto.bool_field(22)
    disable_embed_inlining: bool = betterproto.bool_field(23)
    sign_into_friends: bool = betterproto.bool_field(24)
    animated_avatars: bool = betterproto.bool_field(25)


@dataclass(eq=False, repr=False)
class UsabilityClientUsabilityMetricsNotificationVoiceSettings(betterproto.Message):
    voice_input_gain: float = betterproto.float_field(1)
    voice_output_gain: float = betterproto.float_field(2)
    noise_gate_level: int = betterproto.int32_field(3)
    voice_use_echo_cancellation: bool = betterproto.bool_field(4)
    voice_use_noise_cancellation: bool = betterproto.bool_field(5)
    voice_use_auto_gain_control: bool = betterproto.bool_field(6)
    selected_non_default_mic: bool = betterproto.bool_field(7)
    selected_non_default_output: bool = betterproto.bool_field(8)
    push_to_talk_enabled: bool = betterproto.bool_field(9)
    push_to_mute_enabled: bool = betterproto.bool_field(10)
    play_ptt_sounds: bool = betterproto.bool_field(11)


@dataclass(eq=False, repr=False)
class UsabilityClientUsabilityMetricsNotificationUiState(betterproto.Message):
    friends_list_height: int = betterproto.int32_field(1)
    friends_list_width: int = betterproto.int32_field(2)
    friends_list_docked: bool = betterproto.bool_field(3)
    friends_list_collapsed: bool = betterproto.bool_field(4)
    friends_list_group_chats_height: int = betterproto.int32_field(5)
    friends_list_visible: bool = betterproto.bool_field(6)
    chat_popups_opened: int = betterproto.int32_field(7)
    group_chat_tabs_opened: int = betterproto.int32_field(8)
    friend_chat_tabs_opened: int = betterproto.int32_field(9)
    chat_window_width: int = betterproto.int32_field(10)
    chat_window_height: int = betterproto.int32_field(11)
    category_collapse: "UsabilityClientUsabilityMetricsNotificationUiStateCategoryCollapseState" = (
        betterproto.message_field(12)
    )
    group_chat_left_col_collapsed: int = betterproto.int32_field(13)
    group_chat_right_col_collapsed: int = betterproto.int32_field(14)
    in_one_on_one_voice_chat: bool = betterproto.bool_field(15)
    in_group_voice_chat: bool = betterproto.bool_field(16)


@dataclass(eq=False, repr=False)
class UsabilityClientUsabilityMetricsNotificationUiStateCategoryCollapseState(betterproto.Message):
    in_game_collapsed: bool = betterproto.bool_field(1)
    online_collapsed: bool = betterproto.bool_field(2)
    offline_collapsed: bool = betterproto.bool_field(3)
    game_groups_collapsed: int = betterproto.int32_field(4)
    categories_collapsed: int = betterproto.int32_field(5)


@dataclass(eq=False, repr=False)
class UsabilityClientUsabilityMetricsNotificationMetrics(betterproto.Message):
    friends_count: int = betterproto.int32_field(1)
    friends_category_count: int = betterproto.int32_field(2)
    friends_categorized_count: int = betterproto.int32_field(3)
    friends_online_count: int = betterproto.int32_field(4)
    friends_in_game_count: int = betterproto.int32_field(5)
    friends_in_game_singleton_count: int = betterproto.int32_field(6)
    game_group_count: int = betterproto.int32_field(7)
    friends_favorite_count: int = betterproto.int32_field(8)
    group_chat_count: int = betterproto.int32_field(9)
    group_chat_favorite_count: int = betterproto.int32_field(10)


@dataclass(eq=False, repr=False)
class UsabilityRequestClientUsabilityMetricsNotification(betterproto.Message):
    metrics_run_id: int = betterproto.uint32_field(1)



from __future__ import annotations

import pathlib
import re
import subprocess
from typing import TYPE_CHECKING

import tomli

if TYPE_CHECKING:
    from typing_extensions import TypeAlias

ROOT = pathlib.Path(".").resolve()
PYPROJECT = tomli.load(open(ROOT / "pyproject.toml", "rb"))
try:
    VERSION: str = PYPROJECT["tool"]["poetry"]["version"]
except KeyError:
    raise RuntimeError("Version is not set") from None


RELEASE_LEVELS = {
    "a": "alpha",
    "b": "beta",
    "rc": "candidate",
}

try:
    end_char = re.findall(r"\d+.\d+.\d+([^\d]+).*", VERSION)[0]
except IndexError:
    release_level = "final"
    end_char = " "  # if this was empty, it would raise a ValueError
else:
    release_level = RELEASE_LEVELS[end_char]

    # try to find out the commit hash if checked out from git, and append it to __version__ (since we use this value
    # from setup.py, it gets automatically propagated to an installed copy as well)
    try:
        commit_count = subprocess.check_output(["git", "rev-list", "--count", "HEAD"]).decode("utf-8").strip()
        if commit_count:
            commit_hash = subprocess.check_output(["git", "rev-parse", "--short", "HEAD"]).decode("utf-8").strip()
            if commit_hash:
                VERSION = f"{VERSION}{commit_count}+g{commit_hash}"
    except Exception:
        pass


major, minor, micro = VERSION.split(".")
micro = micro.split(end_char, maxsplit=1)[0]
# TypeAlias to allow for syntax highlighting
file: TypeAlias = f"""\
from typing import NamedTuple

from typing_extensions import Literal

__all__ = (
    "__title__",
    "__author__",
    "__license__",
    "__version__",
    "version_info",
)


class VersionInfo(NamedTuple):
    major: int
    minor: int
    micro: int
    releaselevel: Literal["alpha", "beta", "candidate", "final"]


__title__ = "steam"
__author__ = "Gobot1234"
__license__ = "MIT"
__version__ = "{VERSION}"
version_info = VersionInfo(major={major}, minor={minor}, micro={micro}, releaselevel="{release_level}")
"""


metadata = ROOT / "steam" / "__metadata__.py"
metadata.write_text(file)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: steammessages_clientserver_ucm.proto
# plugin: python-betterproto
# Last updated 09/09/2021

from dataclasses import dataclass
from typing import List

import betterproto


@dataclass(eq=False, repr=False)
class CMsgClientUcmAddScreenshot(betterproto.Message):
    appid: int = betterproto.uint32_field(1)
    filename: str = betterproto.string_field(2)
    thumbname: str = betterproto.string_field(3)
    vr_filename: str = betterproto.string_field(14)
    rtime32_created: int = betterproto.fixed32_field(4)
    width: int = betterproto.uint32_field(5)
    height: int = betterproto.uint32_field(6)
    permissions: int = betterproto.uint32_field(7)
    caption: str = betterproto.string_field(8)
    shortcut_name: str = betterproto.string_field(9)
    tag: List["CMsgClientUcmAddScreenshotTag"] = betterproto.message_field(10)
    tagged_steamid: List[int] = betterproto.fixed64_field(11)
    spoiler_tag: bool = betterproto.bool_field(12)
    tagged_publishedfileid: List[int] = betterproto.uint64_field(13)


@dataclass(eq=False, repr=False)
class CMsgClientUcmAddScreenshotTag(betterproto.Message):
    tag_name: str = betterproto.string_field(1)
    tag_value: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientUcmAddScreenshotResponse(betterproto.Message):
    eresult: int = betterproto.int32_field(1)
    screenshotid: int = betterproto.fixed64_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientUcmDeleteScreenshot(betterproto.Message):
    screenshotid: int = betterproto.fixed64_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientUcmDeleteScreenshotResponse(betterproto.Message):
    eresult: int = betterproto.int32_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientUcmPublishFile(betterproto.Message):
    app_id: int = betterproto.uint32_field(1)
    file_name: str = betterproto.string_field(2)
    preview_file_name: str = betterproto.string_field(3)
    consumer_app_id: int = betterproto.uint32_field(4)
    title: str = betterproto.string_field(5)
    description: str = betterproto.string_field(6)
    tags: List[str] = betterproto.string_field(8)
    workshop_file: bool = betterproto.bool_field(9)
    visibility: int = betterproto.int32_field(10)
    file_type: int = betterproto.uint32_field(11)
    url: str = betterproto.string_field(12)
    video_provider: int = betterproto.uint32_field(13)
    video_account_name: str = betterproto.string_field(14)
    video_identifier: str = betterproto.string_field(15)
    in_progress: bool = betterproto.bool_field(16)


@dataclass(eq=False, repr=False)
class CMsgClientUcmPublishFileResponse(betterproto.Message):
    eresult: int = betterproto.int32_field(1)
    published_file_id: int = betterproto.fixed64_field(2)
    needs_workshop_legal_agreement_acceptance: bool = betterproto.bool_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientUcmUpdatePublishedFile(betterproto.Message):
    app_id: int = betterproto.uint32_field(1)
    published_file_id: int = betterproto.fixed64_field(2)
    file_name: str = betterproto.string_field(3)
    preview_file_name: str = betterproto.string_field(4)
    title: str = betterproto.string_field(5)
    description: str = betterproto.string_field(6)
    tags: List[str] = betterproto.string_field(7)
    visibility: int = betterproto.int32_field(8)
    update_file: bool = betterproto.bool_field(9)
    update_preview_file: bool = betterproto.bool_field(10)
    update_title: bool = betterproto.bool_field(11)
    update_description: bool = betterproto.bool_field(12)
    update_tags: bool = betterproto.bool_field(13)
    update_visibility: bool = betterproto.bool_field(14)
    change_description: str = betterproto.string_field(15)
    update_url: bool = betterproto.bool_field(16)
    url: str = betterproto.string_field(17)
    update_content_manifest: bool = betterproto.bool_field(18)
    content_manifest: int = betterproto.fixed64_field(19)
    metadata: str = betterproto.string_field(20)
    update_metadata: bool = betterproto.bool_field(21)
    language: int = betterproto.int32_field(22)
    removed_kvtags: List[str] = betterproto.string_field(23)
    kvtags: List["CMsgClientUcmUpdatePublishedFileKeyValueTag"] = betterproto.message_field(24)
    previews: List["CMsgClientUcmUpdatePublishedFileAdditionalPreview"] = betterproto.message_field(25)
    previews_to_remove: List[int] = betterproto.int32_field(26)
    clear_in_progress: bool = betterproto.bool_field(27)
    remove_all_kvtags: bool = betterproto.bool_field(28)


@dataclass(eq=False, repr=False)
class CMsgClientUcmUpdatePublishedFileKeyValueTag(betterproto.Message):
    key: str = betterproto.string_field(1)
    value: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientUcmUpdatePublishedFileAdditionalPreview(betterproto.Message):
    original_file_name: str = betterproto.string_field(1)
    internal_file_name: str = betterproto.string_field(2)
    videoid: str = betterproto.string_field(3)
    preview_type: int = betterproto.uint32_field(4)
    update_index: int = betterproto.int32_field(5)


@dataclass(eq=False, repr=False)
class CMsgClientUcmUpdatePublishedFileResponse(betterproto.Message):
    eresult: int = betterproto.int32_field(1)
    needs_workshop_legal_agreement_acceptance: bool = betterproto.bool_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientUcmDeletePublishedFile(betterproto.Message):
    published_file_id: int = betterproto.fixed64_field(1)
    app_id: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientUcmDeletePublishedFileResponse(betterproto.Message):
    eresult: int = betterproto.int32_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientUcmEnumerateUserSubscribedFilesWithUpdates(betterproto.Message):
    app_id: int = betterproto.uint32_field(1)
    start_index: int = betterproto.uint32_field(2)
    start_time: int = betterproto.fixed32_field(3)
    desired_revision: int = betterproto.uint32_field(4)


@dataclass(eq=False, repr=False)
class CMsgClientUcmEnumerateUserSubscribedFilesWithUpdatesResponse(betterproto.Message):
    eresult: int = betterproto.int32_field(1)
    subscribed_files: List[
        "CMsgClientUcmEnumerateUserSubscribedFilesWithUpdatesResponsePublishedFileId"
    ] = betterproto.message_field(2)
    total_results: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientUcmEnumerateUserSubscribedFilesWithUpdatesResponsePublishedFileId(betterproto.Message):
    published_file_id: int = betterproto.fixed64_field(1)
    rtime32_subscribed: int = betterproto.fixed32_field(2)
    appid: int = betterproto.uint32_field(3)
    file_hcontent: int = betterproto.fixed64_field(4)
    file_size: int = betterproto.uint32_field(5)
    rtime32_last_updated: int = betterproto.fixed32_field(6)
    is_depot_content: bool = betterproto.bool_field(7)


@dataclass(eq=False, repr=False)
class CMsgClientUcmPublishedFileUpdated(betterproto.Message):
    published_file_id: int = betterproto.fixed64_field(1)
    app_id: int = betterproto.uint32_field(2)
    time_updated: int = betterproto.uint32_field(3)
    hcontent: int = betterproto.fixed64_field(4)
    file_size: int = betterproto.fixed32_field(5)
    is_depot_content: bool = betterproto.bool_field(6)
    revision: int = betterproto.uint32_field(7)


@dataclass(eq=False, repr=False)
class CMsgClientWorkshopItemChangesRequest(betterproto.Message):
    app_id: int = betterproto.uint32_field(1)
    last_time_updated: int = betterproto.uint32_field(2)
    num_items_needed: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientWorkshopItemChangesResponse(betterproto.Message):
    eresult: int = betterproto.int32_field(1)
    update_time: int = betterproto.uint32_field(2)
    workshop_items: List["CMsgClientWorkshopItemChangesResponseWorkshopItemInfo"] = betterproto.message_field(5)


@dataclass(eq=False, repr=False)
class CMsgClientWorkshopItemChangesResponseWorkshopItemInfo(betterproto.Message):
    published_file_id: int = betterproto.fixed64_field(1)
    time_updated: int = betterproto.uint32_field(2)
    manifest_id: int = betterproto.fixed64_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientUcmSetUserPublishedFileAction(betterproto.Message):
    published_file_id: int = betterproto.fixed64_field(1)
    app_id: int = betterproto.uint32_field(2)
    action: int = betterproto.int32_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientUcmSetUserPublishedFileActionResponse(betterproto.Message):
    eresult: int = betterproto.int32_field(1)


@dataclass(eq=False, repr=False)
class CMsgClientUcmEnumeratePublishedFilesByUserAction(betterproto.Message):
    app_id: int = betterproto.uint32_field(1)
    start_index: int = betterproto.uint32_field(2)
    action: int = betterproto.int32_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientUcmEnumeratePublishedFilesByUserActionResponse(betterproto.Message):
    eresult: int = betterproto.int32_field(1)
    published_files: List[
        "CMsgClientUcmEnumeratePublishedFilesByUserActionResponsePublishedFileId"
    ] = betterproto.message_field(2)
    total_results: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class CMsgClientUcmEnumeratePublishedFilesByUserActionResponsePublishedFileId(betterproto.Message):
    published_file_id: int = betterproto.fixed64_field(1)
    rtime_time_stamp: int = betterproto.fixed32_field(2)


@dataclass(eq=False, repr=False)
class CMsgClientScreenshotsChanged(betterproto.Message):
    pass



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: steammessages_parental.steamclient.proto
# plugin: python-betterproto
# Last updated 09/09/2021

from dataclasses import dataclass
from typing import List

import betterproto


class EProfileCustomizationType(betterproto.Enum):
    Invalid = 0
    RareAchievementShowcase = 1
    GameCollector = 2
    ItemShowcase = 3
    TradeShowcase = 4
    Badges = 5
    FavoriteGame = 6
    ScreenshotShowcase = 7
    CustomText = 8
    FavoriteGroup = 9
    Recommendation = 10
    WorkshopItem = 11
    MyWorkshop = 12
    ArtworkShowcase = 13
    VideoShowcase = 14
    Guides = 15
    MyGuides = 16
    Achievements = 17
    Greenlight = 18
    MyGreenlight = 19
    Salien = 20
    LoyaltyRewardReactions = 21
    SingleArtworkShowcase = 22
    AchievementsCompletionist = 23


class EBanContentCheckResult(betterproto.Enum):
    NotScanned = 0
    Reset = 1
    NeedsChecking = 2
    VeryUnlikely = 5
    Unlikely = 30
    Possible = 50
    Likely = 75
    VeryLikely = 100


class EProfileCustomizationStyle(betterproto.Enum):
    Default = 0
    Selected = 1
    Rarest = 2
    MostRecent = 3
    Random = 4
    HighestRated = 5


class EAgreementType(betterproto.Enum):
    Invalid = -1
    GlobalSSA = 0
    ChinaSSA = 1


class ENotificationSetting(betterproto.Enum):
    UseDefault = 0
    Always = 1
    Never = 2


class ETextFilterSetting(betterproto.Enum):
    SteamLabOptedOut = 0
    Enabled = 1
    EnabledAllowProfanity = 2
    Disabled = 3


@dataclass(eq=False, repr=False)
class GetMutualFriendsForIncomingInvitesRequest(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class IncomingInviteMutualFriendList(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    mutual_friend_account_ids: List[int] = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class GetMutualFriendsForIncomingInvitesResponse(betterproto.Message):
    incoming_invite_mutual_friends_lists: List["IncomingInviteMutualFriendList"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetOwnedGamesRequest(betterproto.Message):
    steamid: int = betterproto.uint64_field(1)
    include_appinfo: bool = betterproto.bool_field(2)
    include_played_free_games: bool = betterproto.bool_field(3)
    appids_filter: List[int] = betterproto.uint32_field(4)
    include_free_sub: bool = betterproto.bool_field(5)
    skip_unvetted_apps: bool = betterproto.bool_field(6)


@dataclass(eq=False, repr=False)
class GetOwnedGamesResponse(betterproto.Message):
    game_count: int = betterproto.uint32_field(1)
    games: List["GetOwnedGamesResponseGame"] = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class GetOwnedGamesResponseGame(betterproto.Message):
    appid: int = betterproto.int32_field(1)
    name: str = betterproto.string_field(2)
    playtime_2_weeks: int = betterproto.int32_field(3)
    playtime_forever: int = betterproto.int32_field(4)
    img_icon_url: str = betterproto.string_field(5)
    img_logo_url: str = betterproto.string_field(6)
    has_community_visible_stats: bool = betterproto.bool_field(7)
    playtime_windows_forever: int = betterproto.int32_field(8)
    playtime_mac_forever: int = betterproto.int32_field(9)
    playtime_linux_forever: int = betterproto.int32_field(10)


@dataclass(eq=False, repr=False)
class GetPlayNextRequest(betterproto.Message):
    max_age_seconds: int = betterproto.uint32_field(1)
    ignore_appids: List[int] = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class GetPlayNextResponse(betterproto.Message):
    last_update_time: int = betterproto.uint32_field(1)
    appids: List[int] = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class GetFriendsGameplayInfoRequest(betterproto.Message):
    appid: int = betterproto.uint32_field(1)


@dataclass(eq=False, repr=False)
class GetFriendsGameplayInfoResponse(betterproto.Message):
    your_info: "GetFriendsGameplayInfoResponseOwnGameplayInfo" = betterproto.message_field(1)
    in_game: List["GetFriendsGameplayInfoResponseFriendsGameplayInfo"] = betterproto.message_field(2)
    played_recently: List["GetFriendsGameplayInfoResponseFriendsGameplayInfo"] = betterproto.message_field(3)
    played_ever: List["GetFriendsGameplayInfoResponseFriendsGameplayInfo"] = betterproto.message_field(4)
    owns: List["GetFriendsGameplayInfoResponseFriendsGameplayInfo"] = betterproto.message_field(5)
    in_wishlist: List["GetFriendsGameplayInfoResponseFriendsGameplayInfo"] = betterproto.message_field(6)


@dataclass(eq=False, repr=False)
class GetFriendsGameplayInfoResponseFriendsGameplayInfo(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    minutes_played: int = betterproto.uint32_field(2)
    minutes_played_forever: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class GetFriendsGameplayInfoResponseOwnGameplayInfo(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    minutes_played: int = betterproto.uint32_field(2)
    minutes_played_forever: int = betterproto.uint32_field(3)
    in_wishlist: bool = betterproto.bool_field(4)
    owned: bool = betterproto.bool_field(5)


@dataclass(eq=False, repr=False)
class GetFriendsAppsActivityRequest(betterproto.Message):
    news_language: str = betterproto.string_field(1)
    request_flags: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class GetFriendsAppsActivityResponse(betterproto.Message):
    trending: List["GetFriendsAppsActivityResponseAppFriendsInfo"] = betterproto.message_field(1)
    recent_purchases: List["GetFriendsAppsActivityResponseAppFriendsInfo"] = betterproto.message_field(2)
    unowned: List["GetFriendsAppsActivityResponseAppFriendsInfo"] = betterproto.message_field(3)
    popular: List["GetFriendsAppsActivityResponseAppFriendsInfo"] = betterproto.message_field(4)
    dont_forget: List["GetFriendsAppsActivityResponseAppFriendsInfo"] = betterproto.message_field(5)
    being_discussed: List["GetFriendsAppsActivityResponseAppFriendsInfo"] = betterproto.message_field(6)
    new_to_group: List["GetFriendsAppsActivityResponseAppFriendsInfo"] = betterproto.message_field(7)
    returned_to_group: List["GetFriendsAppsActivityResponseAppFriendsInfo"] = betterproto.message_field(8)
    active_friend_count: int = betterproto.uint32_field(9)


@dataclass(eq=False, repr=False)
class GetFriendsAppsActivityResponseFriendPlayTime(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    minutes_played_this_week: int = betterproto.uint32_field(2)
    minutes_played_two_weeks: int = betterproto.uint32_field(3)
    minutes_played_forever: int = betterproto.uint32_field(4)
    event_count: int = betterproto.uint32_field(5)


@dataclass(eq=False, repr=False)
class GetFriendsAppsActivityResponseAppFriendsInfo(betterproto.Message):
    appid: int = betterproto.uint32_field(1)
    friends: List["GetFriendsAppsActivityResponseFriendPlayTime"] = betterproto.message_field(2)
    display_order: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class GetGameBadgeLevelsRequest(betterproto.Message):
    appid: int = betterproto.uint32_field(1)


@dataclass(eq=False, repr=False)
class GetGameBadgeLevelsResponse(betterproto.Message):
    player_level: int = betterproto.uint32_field(1)
    badges: List["GetGameBadgeLevelsResponseBadge"] = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class GetGameBadgeLevelsResponseBadge(betterproto.Message):
    level: int = betterproto.int32_field(1)
    series: int = betterproto.int32_field(2)
    border_color: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class GetProfileBackgroundRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    language: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class ProfileItem(betterproto.Message):
    communityitemid: int = betterproto.uint64_field(1)
    image_small: str = betterproto.string_field(2)
    image_large: str = betterproto.string_field(3)
    name: str = betterproto.string_field(4)
    item_title: str = betterproto.string_field(5)
    item_description: str = betterproto.string_field(6)
    appid: int = betterproto.uint32_field(7)
    item_type: int = betterproto.uint32_field(8)
    item_class: int = betterproto.uint32_field(9)
    movie_webm: str = betterproto.string_field(10)
    movie_mp4: str = betterproto.string_field(11)
    movie_webm_small: str = betterproto.string_field(13)
    movie_mp4_small: str = betterproto.string_field(14)
    equipped_flags: int = betterproto.uint32_field(12)


@dataclass(eq=False, repr=False)
class GetProfileBackgroundResponse(betterproto.Message):
    profile_background: "ProfileItem" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class SetProfileBackgroundRequest(betterproto.Message):
    communityitemid: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class SetProfileBackgroundResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetMiniProfileBackgroundRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    language: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class GetMiniProfileBackgroundResponse(betterproto.Message):
    profile_background: "ProfileItem" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class SetMiniProfileBackgroundRequest(betterproto.Message):
    communityitemid: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class SetMiniProfileBackgroundResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetAvatarFrameRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    language: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class GetAvatarFrameResponse(betterproto.Message):
    avatar_frame: "ProfileItem" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class SetAvatarFrameRequest(betterproto.Message):
    communityitemid: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class SetAvatarFrameResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetAnimatedAvatarRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    language: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class GetAnimatedAvatarResponse(betterproto.Message):
    avatar: "ProfileItem" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class SetAnimatedAvatarRequest(betterproto.Message):
    communityitemid: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class SetAnimatedAvatarResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetProfileItemsOwnedRequest(betterproto.Message):
    language: str = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class GetProfileItemsOwnedResponse(betterproto.Message):
    profile_backgrounds: List["ProfileItem"] = betterproto.message_field(1)
    mini_profile_backgrounds: List["ProfileItem"] = betterproto.message_field(2)
    avatar_frames: List["ProfileItem"] = betterproto.message_field(3)
    animated_avatars: List["ProfileItem"] = betterproto.message_field(4)
    profile_modifiers: List["ProfileItem"] = betterproto.message_field(5)


@dataclass(eq=False, repr=False)
class GetProfileItemsEquippedRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    language: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class GetProfileItemsEquippedResponse(betterproto.Message):
    profile_background: "ProfileItem" = betterproto.message_field(1)
    mini_profile_background: "ProfileItem" = betterproto.message_field(2)
    avatar_frame: "ProfileItem" = betterproto.message_field(3)
    animated_avatar: "ProfileItem" = betterproto.message_field(4)
    profile_modifier: "ProfileItem" = betterproto.message_field(5)


@dataclass(eq=False, repr=False)
class SetEquippedProfileItemFlagsRequest(betterproto.Message):
    communityitemid: int = betterproto.uint64_field(1)
    flags: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class SetEquippedProfileItemFlagsResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetEmoticonListRequest(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetEmoticonListResponse(betterproto.Message):
    emoticons: List["GetEmoticonListResponseEmoticon"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetEmoticonListResponseEmoticon(betterproto.Message):
    name: str = betterproto.string_field(1)
    count: int = betterproto.int32_field(2)
    time_last_used: int = betterproto.uint32_field(3)
    use_count: int = betterproto.uint32_field(4)
    time_received: int = betterproto.uint32_field(5)
    appid: int = betterproto.uint32_field(6)


@dataclass(eq=False, repr=False)
class GetAchievementsProgressRequest(betterproto.Message):
    steamid: int = betterproto.uint64_field(1)
    language: str = betterproto.string_field(2)
    appids: List[int] = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class GetAchievementsProgressResponse(betterproto.Message):
    achievement_progress: List["GetAchievementsProgressResponseAchievementProgress"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetAchievementsProgressResponseAchievementProgress(betterproto.Message):
    appid: int = betterproto.uint32_field(1)
    unlocked: int = betterproto.uint32_field(2)
    total: int = betterproto.uint32_field(3)
    percentage: float = betterproto.float_field(4)
    all_unlocked: bool = betterproto.bool_field(5)
    cache_time: int = betterproto.uint32_field(6)


@dataclass(eq=False, repr=False)
class GetFavoriteBadgeRequest(betterproto.Message):
    steamid: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class GetFavoriteBadgeResponse(betterproto.Message):
    has_favorite_badge: bool = betterproto.bool_field(1)
    badgeid: int = betterproto.uint32_field(2)
    communityitemid: int = betterproto.uint64_field(3)
    item_type: int = betterproto.uint32_field(4)
    border_color: int = betterproto.uint32_field(5)
    appid: int = betterproto.uint32_field(6)
    level: int = betterproto.uint32_field(7)


@dataclass(eq=False, repr=False)
class SetFavoriteBadgeRequest(betterproto.Message):
    communityitemid: int = betterproto.uint64_field(1)
    badgeid: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class SetFavoriteBadgeResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetProfileCustomizationRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    include_inactive_customizations: bool = betterproto.bool_field(2)
    include_purchased_customizations: bool = betterproto.bool_field(3)


@dataclass(eq=False, repr=False)
class ProfileCustomizationSlot(betterproto.Message):
    slot: int = betterproto.uint32_field(1)
    appid: int = betterproto.uint32_field(2)
    publishedfileid: int = betterproto.uint64_field(3)
    item_assetid: int = betterproto.uint64_field(4)
    item_contextid: int = betterproto.uint64_field(5)
    notes: str = betterproto.string_field(6)
    title: str = betterproto.string_field(7)
    accountid: int = betterproto.uint32_field(8)
    badgeid: int = betterproto.uint32_field(9)
    border_color: int = betterproto.uint32_field(10)
    item_classid: int = betterproto.uint64_field(11)
    item_instanceid: int = betterproto.uint64_field(12)
    ban_check_result: "EBanContentCheckResult" = betterproto.enum_field(13)


@dataclass(eq=False, repr=False)
class ProfileCustomization(betterproto.Message):
    customization_type: "EProfileCustomizationType" = betterproto.enum_field(1)
    large: bool = betterproto.bool_field(2)
    slots: List["ProfileCustomizationSlot"] = betterproto.message_field(3)
    active: bool = betterproto.bool_field(4)
    customization_style: "EProfileCustomizationStyle" = betterproto.enum_field(5)
    purchaseid: int = betterproto.uint64_field(6)
    level: int = betterproto.uint32_field(7)


@dataclass(eq=False, repr=False)
class ProfileTheme(betterproto.Message):
    theme_id: str = betterproto.string_field(1)
    title: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class ProfilePreferences(betterproto.Message):
    hide_profile_awards: bool = betterproto.bool_field(1)


@dataclass(eq=False, repr=False)
class GetProfileCustomizationResponse(betterproto.Message):
    customizations: List["ProfileCustomization"] = betterproto.message_field(1)
    slots_available: int = betterproto.uint32_field(2)
    profile_theme: "ProfileTheme" = betterproto.message_field(3)
    purchased_customizations: List["GetProfileCustomizationResponsePurchasedCustomization"] = betterproto.message_field(
        4
    )
    profile_preferences: "ProfilePreferences" = betterproto.message_field(5)


@dataclass(eq=False, repr=False)
class GetProfileCustomizationResponsePurchasedCustomization(betterproto.Message):
    purchaseid: int = betterproto.uint64_field(1)
    customization_type: "EProfileCustomizationType" = betterproto.enum_field(2)
    level: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class GetPurchasedProfileCustomizationsRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)


@dataclass(eq=False, repr=False)
class GetPurchasedProfileCustomizationsResponse(betterproto.Message):
    purchased_customizations: List[
        "GetPurchasedProfileCustomizationsResponsePurchasedCustomization"
    ] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetPurchasedProfileCustomizationsResponsePurchasedCustomization(betterproto.Message):
    purchaseid: int = betterproto.uint64_field(1)
    customization_type: "EProfileCustomizationType" = betterproto.enum_field(2)


@dataclass(eq=False, repr=False)
class GetPurchasedAndUpgradedProfileCustomizationsRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)


@dataclass(eq=False, repr=False)
class GetPurchasedAndUpgradedProfileCustomizationsResponse(betterproto.Message):
    purchased_customizations: List[
        "GetPurchasedAndUpgradedProfileCustomizationsResponsePurchasedCustomization"
    ] = betterproto.message_field(1)
    upgraded_customizations: List[
        "GetPurchasedAndUpgradedProfileCustomizationsResponseUpgradedCustomization"
    ] = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class GetPurchasedAndUpgradedProfileCustomizationsResponsePurchasedCustomization(betterproto.Message):
    customization_type: "EProfileCustomizationType" = betterproto.enum_field(1)
    count: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class GetPurchasedAndUpgradedProfileCustomizationsResponseUpgradedCustomization(betterproto.Message):
    customization_type: "EProfileCustomizationType" = betterproto.enum_field(1)
    level: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class GetProfileThemesAvailableRequest(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetProfileThemesAvailableResponse(betterproto.Message):
    profile_themes: List["ProfileTheme"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class SetProfileThemeRequest(betterproto.Message):
    theme_id: str = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class SetProfileThemeResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class SetProfilePreferencesRequest(betterproto.Message):
    profile_preferences: "ProfilePreferences" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class SetProfilePreferencesResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class PostStatusToFriendsRequest(betterproto.Message):
    appid: int = betterproto.uint32_field(1)
    status_text: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class PostStatusToFriendsResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetPostedStatusRequest(betterproto.Message):
    steamid: int = betterproto.uint64_field(1)
    postid: int = betterproto.uint64_field(2)


@dataclass(eq=False, repr=False)
class GetPostedStatusResponse(betterproto.Message):
    accountid: int = betterproto.uint32_field(1)
    postid: int = betterproto.uint64_field(2)
    status_text: str = betterproto.string_field(3)
    deleted: bool = betterproto.bool_field(4)
    appid: int = betterproto.uint32_field(5)


@dataclass(eq=False, repr=False)
class DeletePostedStatusRequest(betterproto.Message):
    postid: int = betterproto.uint64_field(1)


@dataclass(eq=False, repr=False)
class DeletePostedStatusResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetLastPlayedTimesRequest(betterproto.Message):
    min_last_played: int = betterproto.uint32_field(1)


@dataclass(eq=False, repr=False)
class GetLastPlayedTimesResponse(betterproto.Message):
    games: List["GetLastPlayedTimesResponseGame"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetLastPlayedTimesResponseGame(betterproto.Message):
    appid: int = betterproto.int32_field(1)
    last_playtime: int = betterproto.uint32_field(2)
    playtime_2_weeks: int = betterproto.int32_field(3)
    playtime_forever: int = betterproto.int32_field(4)
    first_playtime: int = betterproto.uint32_field(5)
    playtime_windows_forever: int = betterproto.int32_field(6)
    playtime_mac_forever: int = betterproto.int32_field(7)
    playtime_linux_forever: int = betterproto.int32_field(8)
    first_windows_playtime: int = betterproto.uint32_field(9)
    first_mac_playtime: int = betterproto.uint32_field(10)
    first_linux_playtime: int = betterproto.uint32_field(11)
    last_windows_playtime: int = betterproto.uint32_field(12)
    last_mac_playtime: int = betterproto.uint32_field(13)
    last_linux_playtime: int = betterproto.uint32_field(14)


@dataclass(eq=False, repr=False)
class AcceptSsaRequest(betterproto.Message):
    agreement_type: "EAgreementType" = betterproto.enum_field(1)
    time_signed_utc: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class AcceptSsaResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetNicknameListRequest(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetNicknameListResponse(betterproto.Message):
    nicknames: List["GetNicknameListResponsePlayerNickname"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetNicknameListResponsePlayerNickname(betterproto.Message):
    accountid: int = betterproto.fixed32_field(1)
    nickname: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class GetPerFriendPreferencesRequest(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class PerFriendPreferences(betterproto.Message):
    accountid: int = betterproto.fixed32_field(1)
    nickname: str = betterproto.string_field(2)
    notifications_showingame: "ENotificationSetting" = betterproto.enum_field(3)
    notifications_showonline: "ENotificationSetting" = betterproto.enum_field(4)
    notifications_showmessages: "ENotificationSetting" = betterproto.enum_field(5)
    sounds_showingame: "ENotificationSetting" = betterproto.enum_field(6)
    sounds_showonline: "ENotificationSetting" = betterproto.enum_field(7)
    sounds_showmessages: "ENotificationSetting" = betterproto.enum_field(8)
    notifications_sendmobile: "ENotificationSetting" = betterproto.enum_field(9)


@dataclass(eq=False, repr=False)
class GetPerFriendPreferencesResponse(betterproto.Message):
    preferences: List["PerFriendPreferences"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class SetPerFriendPreferencesRequest(betterproto.Message):
    preferences: "PerFriendPreferences" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class SetPerFriendPreferencesResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class AddFriendRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)


@dataclass(eq=False, repr=False)
class AddFriendResponse(betterproto.Message):
    invite_sent: bool = betterproto.bool_field(1)
    friend_relationship: int = betterproto.uint32_field(2)
    result: int = betterproto.int32_field(3)


@dataclass(eq=False, repr=False)
class RemoveFriendRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)


@dataclass(eq=False, repr=False)
class RemoveFriendResponse(betterproto.Message):
    friend_relationship: int = betterproto.uint32_field(1)


@dataclass(eq=False, repr=False)
class IgnoreFriendRequest(betterproto.Message):
    steamid: int = betterproto.fixed64_field(1)
    unignore: bool = betterproto.bool_field(2)


@dataclass(eq=False, repr=False)
class IgnoreFriendResponse(betterproto.Message):
    friend_relationship: int = betterproto.uint32_field(1)


@dataclass(eq=False, repr=False)
class GetCommunityPreferencesRequest(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class CommunityPreferences(betterproto.Message):
    hide_adult_content_violence: bool = betterproto.bool_field(1)
    hide_adult_content_sex: bool = betterproto.bool_field(2)
    parenthesize_nicknames: bool = betterproto.bool_field(4)
    text_filter_setting: "ETextFilterSetting" = betterproto.enum_field(5)
    text_filter_ignore_friends: bool = betterproto.bool_field(6)
    text_filter_words_revision: int = betterproto.uint32_field(7)
    timestamp_updated: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class GetCommunityPreferencesResponse(betterproto.Message):
    preferences: "CommunityPreferences" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class SetCommunityPreferencesRequest(betterproto.Message):
    preferences: "CommunityPreferences" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class SetCommunityPreferencesResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetTextFilterWordsRequest(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class TextFilterWords(betterproto.Message):
    text_filter_custom_banned_words: List[str] = betterproto.string_field(1)
    text_filter_custom_clean_words: List[str] = betterproto.string_field(2)
    text_filter_words_revision: int = betterproto.uint32_field(3)


@dataclass(eq=False, repr=False)
class GetTextFilterWordsResponse(betterproto.Message):
    words: "TextFilterWords" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetNewSteamAnnouncementStateRequest(betterproto.Message):
    language: int = betterproto.int32_field(1)


@dataclass(eq=False, repr=False)
class GetNewSteamAnnouncementStateResponse(betterproto.Message):
    state: int = betterproto.int32_field(1)
    announcement_headline: str = betterproto.string_field(2)
    announcement_url: str = betterproto.string_field(3)
    time_posted: int = betterproto.uint32_field(4)
    announcement_gid: int = betterproto.uint64_field(5)


@dataclass(eq=False, repr=False)
class UpdateSteamAnnouncementLastReadRequest(betterproto.Message):
    announcement_gid: int = betterproto.uint64_field(1)
    time_posted: int = betterproto.uint32_field(2)


@dataclass(eq=False, repr=False)
class UpdateSteamAnnouncementLastReadResponse(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class GetPrivacySettingsRequest(betterproto.Message):
    pass


@dataclass(eq=False, repr=False)
class CPrivacySettings(betterproto.Message):
    privacy_state: int = betterproto.int32_field(1)
    privacy_state_inventory: int = betterproto.int32_field(2)
    privacy_state_gifts: int = betterproto.int32_field(3)
    privacy_state_ownedgames: int = betterproto.int32_field(4)
    privacy_state_playtime: int = betterproto.int32_field(5)
    privacy_state_friendslist: int = betterproto.int32_field(6)


@dataclass(eq=False, repr=False)
class GetPrivacySettingsResponse(betterproto.Message):
    privacy_settings: "CPrivacySettings" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GetDurationControlRequest(betterproto.Message):
    appid: int = betterproto.uint32_field(1)


@dataclass(eq=False, repr=False)
class GetDurationControlResponse(betterproto.Message):
    is_enabled: bool = betterproto.bool_field(1)
    seconds: int = betterproto.int32_field(2)
    seconds_today: int = betterproto.int32_field(3)
    is_steamchina_account: bool = betterproto.bool_field(4)
    is_age_verified: bool = betterproto.bool_field(5)
    seconds_allowed_today: int = betterproto.uint32_field(6)


@dataclass(eq=False, repr=False)
class LastPlayedTimesNotification(betterproto.Message):
    games: List["GetLastPlayedTimesResponseGame"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class FriendNicknameChangedNotification(betterproto.Message):
    accountid: int = betterproto.fixed32_field(1)
    nickname: str = betterproto.string_field(2)
    is_echo_to_self: bool = betterproto.bool_field(3)


@dataclass(eq=False, repr=False)
class FriendEquippedProfileItemsChangedNotification(betterproto.Message):
    accountid: int = betterproto.fixed32_field(1)


@dataclass(eq=False, repr=False)
class NewSteamAnnouncementStateNotification(betterproto.Message):
    state: int = betterproto.int32_field(1)
    announcement_headline: str = betterproto.string_field(2)
    announcement_url: str = betterproto.string_field(3)
    time_posted: int = betterproto.uint32_field(4)
    announcement_gid: int = betterproto.uint64_field(5)


@dataclass(eq=False, repr=False)
class CommunityPreferencesChangedNotification(betterproto.Message):
    preferences: "CommunityPreferences" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class TextFilterWordsChangedNotification(betterproto.Message):
    words: "TextFilterWords" = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class PerFriendPreferencesChangedNotification(betterproto.Message):
    accountid: int = betterproto.fixed32_field(1)
    preferences: "PerFriendPreferences" = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class PrivacySettingsChangedNotification(betterproto.Message):
    privacy_settings: "CPrivacySettings" = betterproto.message_field(1)
